/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output, and Bison version.  */
#define YYBISON 30802

/* Bison version string.  */
#define YYBISON_VERSION "3.8.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1




/* First part of user prologue.  */
#line 22 "../../binutils-ia16-20230531/ld/ldgram.y"

/*

 */

#define DONTDECLARE_MALLOC

#include "sysdep.h"
#include "bfd.h"
#include "bfdlink.h"
#include "ctf-api.h"
#include "ld.h"
#include "ldexp.h"
#include "ldver.h"
#include "ldlang.h"
#include "ldfile.h"
#include "ldemul.h"
#include "ldmisc.h"
#include "ldmain.h"
#include "mri.h"
#include "ldctor.h"
#include "ldlex.h"

#ifndef YYDEBUG
#define YYDEBUG 1
#endif

static enum section_type sectype;
static etree_type *sectype_value;
static lang_memory_region_type *region;

static bool ldgram_had_keep = false, ldgram_cond = true;
static char *ldgram_vers_current_lang = NULL;

#define ERROR_NAME_MAX 20
static char *error_names[ERROR_NAME_MAX];
static int error_index;
#define PUSH_ERROR(x) if (error_index < ERROR_NAME_MAX) error_names[error_index] = x; error_index++;
#define POP_ERROR()   error_index--;

#line 112 "ldgram.c"

# ifndef YY_CAST
#  ifdef __cplusplus
#   define YY_CAST(Type, Val) static_cast<Type> (Val)
#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
#  else
#   define YY_CAST(Type, Val) ((Type) (Val))
#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
#  endif
# endif
# ifndef YY_NULLPTR
#  if defined __cplusplus
#   if 201103L <= __cplusplus
#    define YY_NULLPTR nullptr
#   else
#    define YY_NULLPTR 0
#   endif
#  else
#   define YY_NULLPTR ((void*)0)
#  endif
# endif

/* Use api.header.include to #include this header
   instead of duplicating it here.  */
#ifndef YY_YY_LDGRAM_H_INCLUDED
# define YY_YY_LDGRAM_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    INT = 258,                     /* INT  */
    NAME = 259,                    /* NAME  */
    LNAME = 260,                   /* LNAME  */
    PLUSEQ = 261,                  /* PLUSEQ  */
    MINUSEQ = 262,                 /* MINUSEQ  */
    MULTEQ = 263,                  /* MULTEQ  */
    DIVEQ = 264,                   /* DIVEQ  */
    LSHIFTEQ = 265,                /* LSHIFTEQ  */
    RSHIFTEQ = 266,                /* RSHIFTEQ  */
    ANDEQ = 267,                   /* ANDEQ  */
    OREQ = 268,                    /* OREQ  */
    OROR = 269,                    /* OROR  */
    ANDAND = 270,                  /* ANDAND  */
    EQ = 271,                      /* EQ  */
    NE = 272,                      /* NE  */
    LE = 273,                      /* LE  */
    GE = 274,                      /* GE  */
    LSHIFT = 275,                  /* LSHIFT  */
    RSHIFT = 276,                  /* RSHIFT  */
    UNARY = 277,                   /* UNARY  */
    END = 278,                     /* END  */
    ALIGN_K = 279,                 /* ALIGN_K  */
    BLOCK = 280,                   /* BLOCK  */
    BIND = 281,                    /* BIND  */
    QUAD = 282,                    /* QUAD  */
    SQUAD = 283,                   /* SQUAD  */
    LONG = 284,                    /* LONG  */
    SHORT = 285,                   /* SHORT  */
    BYTE = 286,                    /* BYTE  */
    SECTIONS = 287,                /* SECTIONS  */
    PHDRS = 288,                   /* PHDRS  */
    INSERT_K = 289,                /* INSERT_K  */
    AFTER = 290,                   /* AFTER  */
    BEFORE = 291,                  /* BEFORE  */
    DATA_SEGMENT_ALIGN = 292,      /* DATA_SEGMENT_ALIGN  */
    DATA_SEGMENT_RELRO_END = 293,  /* DATA_SEGMENT_RELRO_END  */
    DATA_SEGMENT_END = 294,        /* DATA_SEGMENT_END  */
    SORT_BY_NAME = 295,            /* SORT_BY_NAME  */
    SORT_BY_ALIGNMENT = 296,       /* SORT_BY_ALIGNMENT  */
    SORT_NONE = 297,               /* SORT_NONE  */
    SORT_BY_INIT_PRIORITY = 298,   /* SORT_BY_INIT_PRIORITY  */
    SIZEOF_HEADERS = 299,          /* SIZEOF_HEADERS  */
    OUTPUT_FORMAT = 300,           /* OUTPUT_FORMAT  */
    FORCE_COMMON_ALLOCATION = 301, /* FORCE_COMMON_ALLOCATION  */
    OUTPUT_ARCH = 302,             /* OUTPUT_ARCH  */
    INHIBIT_COMMON_ALLOCATION = 303, /* INHIBIT_COMMON_ALLOCATION  */
    FORCE_GROUP_ALLOCATION = 304,  /* FORCE_GROUP_ALLOCATION  */
    SEGMENT_START = 305,           /* SEGMENT_START  */
    INCLUDE = 306,                 /* INCLUDE  */
    MEMORY = 307,                  /* MEMORY  */
    REGION_ALIAS = 308,            /* REGION_ALIAS  */
    LD_FEATURE = 309,              /* LD_FEATURE  */
    NOLOAD = 310,                  /* NOLOAD  */
    DSECT = 311,                   /* DSECT  */
    COPY = 312,                    /* COPY  */
    INFO = 313,                    /* INFO  */
    OVERLAY = 314,                 /* OVERLAY  */
    READONLY = 315,                /* READONLY  */
    TYPE = 316,                    /* TYPE  */
    DEFINED = 317,                 /* DEFINED  */
    TARGET_K = 318,                /* TARGET_K  */
    SEARCH_DIR = 319,              /* SEARCH_DIR  */
    MAP = 320,                     /* MAP  */
    ENTRY = 321,                   /* ENTRY  */
    NEXT = 322,                    /* NEXT  */
    SIZEOF = 323,                  /* SIZEOF  */
    ALIGNOF = 324,                 /* ALIGNOF  */
    ADDR = 325,                    /* ADDR  */
    LOADADDR = 326,                /* LOADADDR  */
    MAX_K = 327,                   /* MAX_K  */
    MIN_K = 328,                   /* MIN_K  */
    STARTUP = 329,                 /* STARTUP  */
    HLL = 330,                     /* HLL  */
    SYSLIB = 331,                  /* SYSLIB  */
    FLOAT = 332,                   /* FLOAT  */
    NOFLOAT = 333,                 /* NOFLOAT  */
    NOCROSSREFS = 334,             /* NOCROSSREFS  */
    NOCROSSREFS_TO = 335,          /* NOCROSSREFS_TO  */
    ORIGIN = 336,                  /* ORIGIN  */
    FILL = 337,                    /* FILL  */
    LENGTH = 338,                  /* LENGTH  */
    CREATE_OBJECT_SYMBOLS = 339,   /* CREATE_OBJECT_SYMBOLS  */
    INPUT = 340,                   /* INPUT  */
    GROUP = 341,                   /* GROUP  */
    OUTPUT = 342,                  /* OUTPUT  */
    CONSTRUCTORS = 343,            /* CONSTRUCTORS  */
    ALIGNMOD = 344,                /* ALIGNMOD  */
    AT = 345,                      /* AT  */
    SUBALIGN = 346,                /* SUBALIGN  */
    HIDDEN = 347,                  /* HIDDEN  */
    PROVIDE = 348,                 /* PROVIDE  */
    PROVIDE_HIDDEN = 349,          /* PROVIDE_HIDDEN  */
    AS_NEEDED = 350,               /* AS_NEEDED  */
    CHIP = 351,                    /* CHIP  */
    LIST = 352,                    /* LIST  */
    SECT = 353,                    /* SECT  */
    ABSOLUTE = 354,                /* ABSOLUTE  */
    LOAD = 355,                    /* LOAD  */
    NEWLINE = 356,                 /* NEWLINE  */
    ENDWORD = 357,                 /* ENDWORD  */
    ORDER = 358,                   /* ORDER  */
    NAMEWORD = 359,                /* NAMEWORD  */
    ASSERT_K = 360,                /* ASSERT_K  */
    LOG2CEIL = 361,                /* LOG2CEIL  */
    FORMAT = 362,                  /* FORMAT  */
    PUBLIC = 363,                  /* PUBLIC  */
    DEFSYMEND = 364,               /* DEFSYMEND  */
    BASE = 365,                    /* BASE  */
    ALIAS = 366,                   /* ALIAS  */
    TRUNCATE = 367,                /* TRUNCATE  */
    REL = 368,                     /* REL  */
    INPUT_SCRIPT = 369,            /* INPUT_SCRIPT  */
    INPUT_MRI_SCRIPT = 370,        /* INPUT_MRI_SCRIPT  */
    INPUT_DEFSYM = 371,            /* INPUT_DEFSYM  */
    CASE = 372,                    /* CASE  */
    EXTERN = 373,                  /* EXTERN  */
    START = 374,                   /* START  */
    VERS_TAG = 375,                /* VERS_TAG  */
    VERS_IDENTIFIER = 376,         /* VERS_IDENTIFIER  */
    GLOBAL = 377,                  /* GLOBAL  */
    LOCAL = 378,                   /* LOCAL  */
    VERSIONK = 379,                /* VERSIONK  */
    INPUT_VERSION_SCRIPT = 380,    /* INPUT_VERSION_SCRIPT  */
    KEEP = 381,                    /* KEEP  */
    ONLY_IF_RO = 382,              /* ONLY_IF_RO  */
    ONLY_IF_RW = 383,              /* ONLY_IF_RW  */
    SPECIAL = 384,                 /* SPECIAL  */
    INPUT_SECTION_FLAGS = 385,     /* INPUT_SECTION_FLAGS  */
    ALIGN_WITH_INPUT = 386,        /* ALIGN_WITH_INPUT  */
    EXCLUDE_FILE = 387,            /* EXCLUDE_FILE  */
    CONSTANT = 388,                /* CONSTANT  */
    INPUT_DYNAMIC_LIST = 389       /* INPUT_DYNAMIC_LIST  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif
/* Token kinds.  */
#define YYEMPTY -2
#define YYEOF 0
#define YYerror 256
#define YYUNDEF 257
#define INT 258
#define NAME 259
#define LNAME 260
#define PLUSEQ 261
#define MINUSEQ 262
#define MULTEQ 263
#define DIVEQ 264
#define LSHIFTEQ 265
#define RSHIFTEQ 266
#define ANDEQ 267
#define OREQ 268
#define OROR 269
#define ANDAND 270
#define EQ 271
#define NE 272
#define LE 273
#define GE 274
#define LSHIFT 275
#define RSHIFT 276
#define UNARY 277
#define END 278
#define ALIGN_K 279
#define BLOCK 280
#define BIND 281
#define QUAD 282
#define SQUAD 283
#define LONG 284
#define SHORT 285
#define BYTE 286
#define SECTIONS 287
#define PHDRS 288
#define INSERT_K 289
#define AFTER 290
#define BEFORE 291
#define DATA_SEGMENT_ALIGN 292
#define DATA_SEGMENT_RELRO_END 293
#define DATA_SEGMENT_END 294
#define SORT_BY_NAME 295
#define SORT_BY_ALIGNMENT 296
#define SORT_NONE 297
#define SORT_BY_INIT_PRIORITY 298
#define SIZEOF_HEADERS 299
#define OUTPUT_FORMAT 300
#define FORCE_COMMON_ALLOCATION 301
#define OUTPUT_ARCH 302
#define INHIBIT_COMMON_ALLOCATION 303
#define FORCE_GROUP_ALLOCATION 304
#define SEGMENT_START 305
#define INCLUDE 306
#define MEMORY 307
#define REGION_ALIAS 308
#define LD_FEATURE 309
#define NOLOAD 310
#define DSECT 311
#define COPY 312
#define INFO 313
#define OVERLAY 314
#define READONLY 315
#define TYPE 316
#define DEFINED 317
#define TARGET_K 318
#define SEARCH_DIR 319
#define MAP 320
#define ENTRY 321
#define NEXT 322
#define SIZEOF 323
#define ALIGNOF 324
#define ADDR 325
#define LOADADDR 326
#define MAX_K 327
#define MIN_K 328
#define STARTUP 329
#define HLL 330
#define SYSLIB 331
#define FLOAT 332
#define NOFLOAT 333
#define NOCROSSREFS 334
#define NOCROSSREFS_TO 335
#define ORIGIN 336
#define FILL 337
#define LENGTH 338
#define CREATE_OBJECT_SYMBOLS 339
#define INPUT 340
#define GROUP 341
#define OUTPUT 342
#define CONSTRUCTORS 343
#define ALIGNMOD 344
#define AT 345
#define SUBALIGN 346
#define HIDDEN 347
#define PROVIDE 348
#define PROVIDE_HIDDEN 349
#define AS_NEEDED 350
#define CHIP 351
#define LIST 352
#define SECT 353
#define ABSOLUTE 354
#define LOAD 355
#define NEWLINE 356
#define ENDWORD 357
#define ORDER 358
#define NAMEWORD 359
#define ASSERT_K 360
#define LOG2CEIL 361
#define FORMAT 362
#define PUBLIC 363
#define DEFSYMEND 364
#define BASE 365
#define ALIAS 366
#define TRUNCATE 367
#define REL 368
#define INPUT_SCRIPT 369
#define INPUT_MRI_SCRIPT 370
#define INPUT_DEFSYM 371
#define CASE 372
#define EXTERN 373
#define START 374
#define VERS_TAG 375
#define VERS_IDENTIFIER 376
#define GLOBAL 377
#define LOCAL 378
#define VERSIONK 379
#define INPUT_VERSION_SCRIPT 380
#define KEEP 381
#define ONLY_IF_RO 382
#define ONLY_IF_RW 383
#define SPECIAL 384
#define INPUT_SECTION_FLAGS 385
#define ALIGN_WITH_INPUT 386
#define EXCLUDE_FILE 387
#define CONSTANT 388
#define INPUT_DYNAMIC_LIST 389

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 62 "../../binutils-ia16-20230531/ld/ldgram.y"

  bfd_vma integer;
  struct big_int
    {
      bfd_vma integer;
      char *str;
    } bigint;
  fill_type *fill;
  char *name;
  const char *cname;
  struct wildcard_spec wildcard;
  struct wildcard_list *wildcard_list;
  struct name_list *name_list;
  struct flag_info_list *flag_info_list;
  struct flag_info *flag_info;
  int token;
  union etree_union *etree;
  struct phdr_info
    {
      bool filehdr;
      bool phdrs;
      union etree_union *at;
      union etree_union *flags;
    } phdr;
  struct lang_nocrossref *nocrossref;
  struct lang_output_section_phdr_list *section_phdr;
  struct bfd_elf_version_deps *deflist;
  struct bfd_elf_version_expr *versyms;
  struct bfd_elf_version_tree *versnode;

#line 464 "ldgram.c"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;


int yyparse (void);


#endif /* !YY_YY_LDGRAM_H_INCLUDED  */
/* Symbol kind.  */
enum yysymbol_kind_t
{
  YYSYMBOL_YYEMPTY = -2,
  YYSYMBOL_YYEOF = 0,                      /* "end of file"  */
  YYSYMBOL_YYerror = 1,                    /* error  */
  YYSYMBOL_YYUNDEF = 2,                    /* "invalid token"  */
  YYSYMBOL_INT = 3,                        /* INT  */
  YYSYMBOL_NAME = 4,                       /* NAME  */
  YYSYMBOL_LNAME = 5,                      /* LNAME  */
  YYSYMBOL_PLUSEQ = 6,                     /* PLUSEQ  */
  YYSYMBOL_MINUSEQ = 7,                    /* MINUSEQ  */
  YYSYMBOL_MULTEQ = 8,                     /* MULTEQ  */
  YYSYMBOL_DIVEQ = 9,                      /* DIVEQ  */
  YYSYMBOL_10_ = 10,                       /* '='  */
  YYSYMBOL_LSHIFTEQ = 11,                  /* LSHIFTEQ  */
  YYSYMBOL_RSHIFTEQ = 12,                  /* RSHIFTEQ  */
  YYSYMBOL_ANDEQ = 13,                     /* ANDEQ  */
  YYSYMBOL_OREQ = 14,                      /* OREQ  */
  YYSYMBOL_15_ = 15,                       /* '?'  */
  YYSYMBOL_16_ = 16,                       /* ':'  */
  YYSYMBOL_OROR = 17,                      /* OROR  */
  YYSYMBOL_ANDAND = 18,                    /* ANDAND  */
  YYSYMBOL_19_ = 19,                       /* '|'  */
  YYSYMBOL_20_ = 20,                       /* '^'  */
  YYSYMBOL_21_ = 21,                       /* '&'  */
  YYSYMBOL_EQ = 22,                        /* EQ  */
  YYSYMBOL_NE = 23,                        /* NE  */
  YYSYMBOL_24_ = 24,                       /* '<'  */
  YYSYMBOL_25_ = 25,                       /* '>'  */
  YYSYMBOL_LE = 26,                        /* LE  */
  YYSYMBOL_GE = 27,                        /* GE  */
  YYSYMBOL_LSHIFT = 28,                    /* LSHIFT  */
  YYSYMBOL_RSHIFT = 29,                    /* RSHIFT  */
  YYSYMBOL_30_ = 30,                       /* '+'  */
  YYSYMBOL_31_ = 31,                       /* '-'  */
  YYSYMBOL_32_ = 32,                       /* '*'  */
  YYSYMBOL_33_ = 33,                       /* '/'  */
  YYSYMBOL_34_ = 34,                       /* '%'  */
  YYSYMBOL_UNARY = 35,                     /* UNARY  */
  YYSYMBOL_END = 36,                       /* END  */
  YYSYMBOL_37_ = 37,                       /* '('  */
  YYSYMBOL_ALIGN_K = 38,                   /* ALIGN_K  */
  YYSYMBOL_BLOCK = 39,                     /* BLOCK  */
  YYSYMBOL_BIND = 40,                      /* BIND  */
  YYSYMBOL_QUAD = 41,                      /* QUAD  */
  YYSYMBOL_SQUAD = 42,                     /* SQUAD  */
  YYSYMBOL_LONG = 43,                      /* LONG  */
  YYSYMBOL_SHORT = 44,                     /* SHORT  */
  YYSYMBOL_BYTE = 45,                      /* BYTE  */
  YYSYMBOL_SECTIONS = 46,                  /* SECTIONS  */
  YYSYMBOL_PHDRS = 47,                     /* PHDRS  */
  YYSYMBOL_INSERT_K = 48,                  /* INSERT_K  */
  YYSYMBOL_AFTER = 49,                     /* AFTER  */
  YYSYMBOL_BEFORE = 50,                    /* BEFORE  */
  YYSYMBOL_DATA_SEGMENT_ALIGN = 51,        /* DATA_SEGMENT_ALIGN  */
  YYSYMBOL_DATA_SEGMENT_RELRO_END = 52,    /* DATA_SEGMENT_RELRO_END  */
  YYSYMBOL_DATA_SEGMENT_END = 53,          /* DATA_SEGMENT_END  */
  YYSYMBOL_SORT_BY_NAME = 54,              /* SORT_BY_NAME  */
  YYSYMBOL_SORT_BY_ALIGNMENT = 55,         /* SORT_BY_ALIGNMENT  */
  YYSYMBOL_SORT_NONE = 56,                 /* SORT_NONE  */
  YYSYMBOL_SORT_BY_INIT_PRIORITY = 57,     /* SORT_BY_INIT_PRIORITY  */
  YYSYMBOL_58_ = 58,                       /* '{'  */
  YYSYMBOL_59_ = 59,                       /* '}'  */
  YYSYMBOL_SIZEOF_HEADERS = 60,            /* SIZEOF_HEADERS  */
  YYSYMBOL_OUTPUT_FORMAT = 61,             /* OUTPUT_FORMAT  */
  YYSYMBOL_FORCE_COMMON_ALLOCATION = 62,   /* FORCE_COMMON_ALLOCATION  */
  YYSYMBOL_OUTPUT_ARCH = 63,               /* OUTPUT_ARCH  */
  YYSYMBOL_INHIBIT_COMMON_ALLOCATION = 64, /* INHIBIT_COMMON_ALLOCATION  */
  YYSYMBOL_FORCE_GROUP_ALLOCATION = 65,    /* FORCE_GROUP_ALLOCATION  */
  YYSYMBOL_SEGMENT_START = 66,             /* SEGMENT_START  */
  YYSYMBOL_INCLUDE = 67,                   /* INCLUDE  */
  YYSYMBOL_MEMORY = 68,                    /* MEMORY  */
  YYSYMBOL_REGION_ALIAS = 69,              /* REGION_ALIAS  */
  YYSYMBOL_LD_FEATURE = 70,                /* LD_FEATURE  */
  YYSYMBOL_NOLOAD = 71,                    /* NOLOAD  */
  YYSYMBOL_DSECT = 72,                     /* DSECT  */
  YYSYMBOL_COPY = 73,                      /* COPY  */
  YYSYMBOL_INFO = 74,                      /* INFO  */
  YYSYMBOL_OVERLAY = 75,                   /* OVERLAY  */
  YYSYMBOL_READONLY = 76,                  /* READONLY  */
  YYSYMBOL_TYPE = 77,                      /* TYPE  */
  YYSYMBOL_DEFINED = 78,                   /* DEFINED  */
  YYSYMBOL_TARGET_K = 79,                  /* TARGET_K  */
  YYSYMBOL_SEARCH_DIR = 80,                /* SEARCH_DIR  */
  YYSYMBOL_MAP = 81,                       /* MAP  */
  YYSYMBOL_ENTRY = 82,                     /* ENTRY  */
  YYSYMBOL_NEXT = 83,                      /* NEXT  */
  YYSYMBOL_SIZEOF = 84,                    /* SIZEOF  */
  YYSYMBOL_ALIGNOF = 85,                   /* ALIGNOF  */
  YYSYMBOL_ADDR = 86,                      /* ADDR  */
  YYSYMBOL_LOADADDR = 87,                  /* LOADADDR  */
  YYSYMBOL_MAX_K = 88,                     /* MAX_K  */
  YYSYMBOL_MIN_K = 89,                     /* MIN_K  */
  YYSYMBOL_STARTUP = 90,                   /* STARTUP  */
  YYSYMBOL_HLL = 91,                       /* HLL  */
  YYSYMBOL_SYSLIB = 92,                    /* SYSLIB  */
  YYSYMBOL_FLOAT = 93,                     /* FLOAT  */
  YYSYMBOL_NOFLOAT = 94,                   /* NOFLOAT  */
  YYSYMBOL_NOCROSSREFS = 95,               /* NOCROSSREFS  */
  YYSYMBOL_NOCROSSREFS_TO = 96,            /* NOCROSSREFS_TO  */
  YYSYMBOL_ORIGIN = 97,                    /* ORIGIN  */
  YYSYMBOL_FILL = 98,                      /* FILL  */
  YYSYMBOL_LENGTH = 99,                    /* LENGTH  */
  YYSYMBOL_CREATE_OBJECT_SYMBOLS = 100,    /* CREATE_OBJECT_SYMBOLS  */
  YYSYMBOL_INPUT = 101,                    /* INPUT  */
  YYSYMBOL_GROUP = 102,                    /* GROUP  */
  YYSYMBOL_OUTPUT = 103,                   /* OUTPUT  */
  YYSYMBOL_CONSTRUCTORS = 104,             /* CONSTRUCTORS  */
  YYSYMBOL_ALIGNMOD = 105,                 /* ALIGNMOD  */
  YYSYMBOL_AT = 106,                       /* AT  */
  YYSYMBOL_SUBALIGN = 107,                 /* SUBALIGN  */
  YYSYMBOL_HIDDEN = 108,                   /* HIDDEN  */
  YYSYMBOL_PROVIDE = 109,                  /* PROVIDE  */
  YYSYMBOL_PROVIDE_HIDDEN = 110,           /* PROVIDE_HIDDEN  */
  YYSYMBOL_AS_NEEDED = 111,                /* AS_NEEDED  */
  YYSYMBOL_CHIP = 112,                     /* CHIP  */
  YYSYMBOL_LIST = 113,                     /* LIST  */
  YYSYMBOL_SECT = 114,                     /* SECT  */
  YYSYMBOL_ABSOLUTE = 115,                 /* ABSOLUTE  */
  YYSYMBOL_LOAD = 116,                     /* LOAD  */
  YYSYMBOL_NEWLINE = 117,                  /* NEWLINE  */
  YYSYMBOL_ENDWORD = 118,                  /* ENDWORD  */
  YYSYMBOL_ORDER = 119,                    /* ORDER  */
  YYSYMBOL_NAMEWORD = 120,                 /* NAMEWORD  */
  YYSYMBOL_ASSERT_K = 121,                 /* ASSERT_K  */
  YYSYMBOL_LOG2CEIL = 122,                 /* LOG2CEIL  */
  YYSYMBOL_FORMAT = 123,                   /* FORMAT  */
  YYSYMBOL_PUBLIC = 124,                   /* PUBLIC  */
  YYSYMBOL_DEFSYMEND = 125,                /* DEFSYMEND  */
  YYSYMBOL_BASE = 126,                     /* BASE  */
  YYSYMBOL_ALIAS = 127,                    /* ALIAS  */
  YYSYMBOL_TRUNCATE = 128,                 /* TRUNCATE  */
  YYSYMBOL_REL = 129,                      /* REL  */
  YYSYMBOL_INPUT_SCRIPT = 130,             /* INPUT_SCRIPT  */
  YYSYMBOL_INPUT_MRI_SCRIPT = 131,         /* INPUT_MRI_SCRIPT  */
  YYSYMBOL_INPUT_DEFSYM = 132,             /* INPUT_DEFSYM  */
  YYSYMBOL_CASE = 133,                     /* CASE  */
  YYSYMBOL_EXTERN = 134,                   /* EXTERN  */
  YYSYMBOL_START = 135,                    /* START  */
  YYSYMBOL_VERS_TAG = 136,                 /* VERS_TAG  */
  YYSYMBOL_VERS_IDENTIFIER = 137,          /* VERS_IDENTIFIER  */
  YYSYMBOL_GLOBAL = 138,                   /* GLOBAL  */
  YYSYMBOL_LOCAL = 139,                    /* LOCAL  */
  YYSYMBOL_VERSIONK = 140,                 /* VERSIONK  */
  YYSYMBOL_INPUT_VERSION_SCRIPT = 141,     /* INPUT_VERSION_SCRIPT  */
  YYSYMBOL_KEEP = 142,                     /* KEEP  */
  YYSYMBOL_ONLY_IF_RO = 143,               /* ONLY_IF_RO  */
  YYSYMBOL_ONLY_IF_RW = 144,               /* ONLY_IF_RW  */
  YYSYMBOL_SPECIAL = 145,                  /* SPECIAL  */
  YYSYMBOL_INPUT_SECTION_FLAGS = 146,      /* INPUT_SECTION_FLAGS  */
  YYSYMBOL_ALIGN_WITH_INPUT = 147,         /* ALIGN_WITH_INPUT  */
  YYSYMBOL_EXCLUDE_FILE = 148,             /* EXCLUDE_FILE  */
  YYSYMBOL_CONSTANT = 149,                 /* CONSTANT  */
  YYSYMBOL_INPUT_DYNAMIC_LIST = 150,       /* INPUT_DYNAMIC_LIST  */
  YYSYMBOL_151_ = 151,                     /* ','  */
  YYSYMBOL_152_ = 152,                     /* ')'  */
  YYSYMBOL_153_ = 153,                     /* ';'  */
  YYSYMBOL_154_ = 154,                     /* '['  */
  YYSYMBOL_155_ = 155,                     /* ']'  */
  YYSYMBOL_156_ = 156,                     /* '!'  */
  YYSYMBOL_157_ = 157,                     /* '~'  */
  YYSYMBOL_YYACCEPT = 158,                 /* $accept  */
  YYSYMBOL_file = 159,                     /* file  */
  YYSYMBOL_filename = 160,                 /* filename  */
  YYSYMBOL_defsym_expr = 161,              /* defsym_expr  */
  YYSYMBOL_162_1 = 162,                    /* $@1  */
  YYSYMBOL_mri_script_file = 163,          /* mri_script_file  */
  YYSYMBOL_164_2 = 164,                    /* $@2  */
  YYSYMBOL_mri_script_lines = 165,         /* mri_script_lines  */
  YYSYMBOL_mri_script_command = 166,       /* mri_script_command  */
  YYSYMBOL_167_3 = 167,                    /* $@3  */
  YYSYMBOL_ordernamelist = 168,            /* ordernamelist  */
  YYSYMBOL_mri_load_name_list = 169,       /* mri_load_name_list  */
  YYSYMBOL_mri_abs_name_list = 170,        /* mri_abs_name_list  */
  YYSYMBOL_casesymlist = 171,              /* casesymlist  */
  YYSYMBOL_extern_name_list = 172,         /* extern_name_list  */
  YYSYMBOL_cond_extern_name_list = 173,    /* cond_extern_name_list  */
  YYSYMBOL_174_4 = 174,                    /* @4  */
  YYSYMBOL_script_file = 175,              /* script_file  */
  YYSYMBOL_176_5 = 176,                    /* $@5  */
  YYSYMBOL_ifile_list = 177,               /* ifile_list  */
  YYSYMBOL_ifile_p1 = 178,                 /* ifile_p1  */
  YYSYMBOL_179_6 = 179,                    /* $@6  */
  YYSYMBOL_180_7 = 180,                    /* $@7  */
  YYSYMBOL_181_8 = 181,                    /* $@8  */
  YYSYMBOL_input_list = 182,               /* input_list  */
  YYSYMBOL_183_9 = 183,                    /* $@9  */
  YYSYMBOL_input_list1 = 184,              /* input_list1  */
  YYSYMBOL_185_10 = 185,                   /* @10  */
  YYSYMBOL_186_11 = 186,                   /* @11  */
  YYSYMBOL_187_12 = 187,                   /* @12  */
  YYSYMBOL_cond_input_list = 188,          /* cond_input_list  */
  YYSYMBOL_189_13 = 189,                   /* @13  */
  YYSYMBOL_sections = 190,                 /* sections  */
  YYSYMBOL_sec_or_group_p1 = 191,          /* sec_or_group_p1  */
  YYSYMBOL_statement_anywhere = 192,       /* statement_anywhere  */
  YYSYMBOL_193_14 = 193,                   /* $@14  */
  YYSYMBOL_wildcard_name = 194,            /* wildcard_name  */
  YYSYMBOL_wildcard_maybe_exclude = 195,   /* wildcard_maybe_exclude  */
  YYSYMBOL_filename_spec = 196,            /* filename_spec  */
  YYSYMBOL_section_name_spec = 197,        /* section_name_spec  */
  YYSYMBOL_sect_flag_list = 198,           /* sect_flag_list  */
  YYSYMBOL_sect_flags = 199,               /* sect_flags  */
  YYSYMBOL_exclude_name_list = 200,        /* exclude_name_list  */
  YYSYMBOL_section_name_list = 201,        /* section_name_list  */
  YYSYMBOL_input_section_spec_no_keep = 202, /* input_section_spec_no_keep  */
  YYSYMBOL_input_section_spec = 203,       /* input_section_spec  */
  YYSYMBOL_204_15 = 204,                   /* $@15  */
  YYSYMBOL_statement = 205,                /* statement  */
  YYSYMBOL_206_16 = 206,                   /* $@16  */
  YYSYMBOL_207_17 = 207,                   /* $@17  */
  YYSYMBOL_statement_list = 208,           /* statement_list  */
  YYSYMBOL_statement_list_opt = 209,       /* statement_list_opt  */
  YYSYMBOL_length = 210,                   /* length  */
  YYSYMBOL_fill_exp = 211,                 /* fill_exp  */
  YYSYMBOL_fill_opt = 212,                 /* fill_opt  */
  YYSYMBOL_assign_op = 213,                /* assign_op  */
  YYSYMBOL_separator = 214,                /* separator  */
  YYSYMBOL_assignment = 215,               /* assignment  */
  YYSYMBOL_opt_comma = 216,                /* opt_comma  */
  YYSYMBOL_memory = 217,                   /* memory  */
  YYSYMBOL_memory_spec_list_opt = 218,     /* memory_spec_list_opt  */
  YYSYMBOL_memory_spec_list = 219,         /* memory_spec_list  */
  YYSYMBOL_memory_spec = 220,              /* memory_spec  */
  YYSYMBOL_221_18 = 221,                   /* $@18  */
  YYSYMBOL_222_19 = 222,                   /* $@19  */
  YYSYMBOL_origin_spec = 223,              /* origin_spec  */
  YYSYMBOL_length_spec = 224,              /* length_spec  */
  YYSYMBOL_attributes_opt = 225,           /* attributes_opt  */
  YYSYMBOL_attributes_list = 226,          /* attributes_list  */
  YYSYMBOL_attributes_string = 227,        /* attributes_string  */
  YYSYMBOL_startup = 228,                  /* startup  */
  YYSYMBOL_high_level_library = 229,       /* high_level_library  */
  YYSYMBOL_high_level_library_NAME_list = 230, /* high_level_library_NAME_list  */
  YYSYMBOL_low_level_library = 231,        /* low_level_library  */
  YYSYMBOL_low_level_library_NAME_list = 232, /* low_level_library_NAME_list  */
  YYSYMBOL_floating_point_support = 233,   /* floating_point_support  */
  YYSYMBOL_nocrossref_list = 234,          /* nocrossref_list  */
  YYSYMBOL_paren_script_name = 235,        /* paren_script_name  */
  YYSYMBOL_236_20 = 236,                   /* $@20  */
  YYSYMBOL_mustbe_exp = 237,               /* mustbe_exp  */
  YYSYMBOL_238_21 = 238,                   /* $@21  */
  YYSYMBOL_exp = 239,                      /* exp  */
  YYSYMBOL_240_22 = 240,                   /* $@22  */
  YYSYMBOL_241_23 = 241,                   /* $@23  */
  YYSYMBOL_memspec_at_opt = 242,           /* memspec_at_opt  */
  YYSYMBOL_opt_at = 243,                   /* opt_at  */
  YYSYMBOL_opt_align = 244,                /* opt_align  */
  YYSYMBOL_opt_align_with_input = 245,     /* opt_align_with_input  */
  YYSYMBOL_opt_subalign = 246,             /* opt_subalign  */
  YYSYMBOL_sect_constraint = 247,          /* sect_constraint  */
  YYSYMBOL_section = 248,                  /* section  */
  YYSYMBOL_249_24 = 249,                   /* $@24  */
  YYSYMBOL_250_25 = 250,                   /* $@25  */
  YYSYMBOL_251_26 = 251,                   /* $@26  */
  YYSYMBOL_252_27 = 252,                   /* $@27  */
  YYSYMBOL_253_28 = 253,                   /* $@28  */
  YYSYMBOL_254_29 = 254,                   /* $@29  */
  YYSYMBOL_255_30 = 255,                   /* $@30  */
  YYSYMBOL_256_31 = 256,                   /* $@31  */
  YYSYMBOL_257_32 = 257,                   /* $@32  */
  YYSYMBOL_258_33 = 258,                   /* $@33  */
  YYSYMBOL_259_34 = 259,                   /* $@34  */
  YYSYMBOL_type = 260,                     /* type  */
  YYSYMBOL_atype = 261,                    /* atype  */
  YYSYMBOL_opt_exp_with_type = 262,        /* opt_exp_with_type  */
  YYSYMBOL_opt_exp_without_type = 263,     /* opt_exp_without_type  */
  YYSYMBOL_opt_nocrossrefs = 264,          /* opt_nocrossrefs  */
  YYSYMBOL_memspec_opt = 265,              /* memspec_opt  */
  YYSYMBOL_phdr_opt = 266,                 /* phdr_opt  */
  YYSYMBOL_overlay_section = 267,          /* overlay_section  */
  YYSYMBOL_268_35 = 268,                   /* $@35  */
  YYSYMBOL_269_36 = 269,                   /* $@36  */
  YYSYMBOL_270_37 = 270,                   /* $@37  */
  YYSYMBOL_phdrs = 271,                    /* phdrs  */
  YYSYMBOL_phdr_list = 272,                /* phdr_list  */
  YYSYMBOL_phdr = 273,                     /* phdr  */
  YYSYMBOL_274_38 = 274,                   /* $@38  */
  YYSYMBOL_275_39 = 275,                   /* $@39  */
  YYSYMBOL_phdr_type = 276,                /* phdr_type  */
  YYSYMBOL_phdr_qualifiers = 277,          /* phdr_qualifiers  */
  YYSYMBOL_phdr_val = 278,                 /* phdr_val  */
  YYSYMBOL_dynamic_list_file = 279,        /* dynamic_list_file  */
  YYSYMBOL_280_40 = 280,                   /* $@40  */
  YYSYMBOL_dynamic_list_nodes = 281,       /* dynamic_list_nodes  */
  YYSYMBOL_dynamic_list_node = 282,        /* dynamic_list_node  */
  YYSYMBOL_dynamic_list_tag = 283,         /* dynamic_list_tag  */
  YYSYMBOL_version_script_file = 284,      /* version_script_file  */
  YYSYMBOL_285_41 = 285,                   /* $@41  */
  YYSYMBOL_version = 286,                  /* version  */
  YYSYMBOL_287_42 = 287,                   /* $@42  */
  YYSYMBOL_vers_nodes = 288,               /* vers_nodes  */
  YYSYMBOL_vers_node = 289,                /* vers_node  */
  YYSYMBOL_verdep = 290,                   /* verdep  */
  YYSYMBOL_vers_tag = 291,                 /* vers_tag  */
  YYSYMBOL_vers_defns = 292,               /* vers_defns  */
  YYSYMBOL_293_43 = 293,                   /* @43  */
  YYSYMBOL_294_44 = 294,                   /* @44  */
  YYSYMBOL_opt_semicolon = 295             /* opt_semicolon  */
};
typedef enum yysymbol_kind_t yysymbol_kind_t;




#ifdef short
# undef short
#endif

/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
   <limits.h> and (if available) <stdint.h> are included
   so that the code can choose integer types of a good width.  */

#ifndef __PTRDIFF_MAX__
# include <limits.h> /* INFRINGES ON USER NAME SPACE */
# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
#  define YY_STDINT_H
# endif
#endif

/* Narrow types that promote to a signed type and that can represent a
   signed or unsigned integer of at least N bits.  In tables they can
   save space and decrease cache pressure.  Promoting to a signed type
   helps avoid bugs in integer arithmetic.  */

#ifdef __INT_LEAST8_MAX__
typedef __INT_LEAST8_TYPE__ yytype_int8;
#elif defined YY_STDINT_H
typedef int_least8_t yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef __INT_LEAST16_MAX__
typedef __INT_LEAST16_TYPE__ yytype_int16;
#elif defined YY_STDINT_H
typedef int_least16_t yytype_int16;
#else
typedef short yytype_int16;
#endif

/* Work around bug in HP-UX 11.23, which defines these macros
   incorrectly for preprocessor constants.  This workaround can likely
   be removed in 2023, as HPE has promised support for HP-UX 11.23
   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
#ifdef __hpux
# undef UINT_LEAST8_MAX
# undef UINT_LEAST16_MAX
# define UINT_LEAST8_MAX 255
# define UINT_LEAST16_MAX 65535
#endif

#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
typedef __UINT_LEAST8_TYPE__ yytype_uint8;
#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST8_MAX <= INT_MAX)
typedef uint_least8_t yytype_uint8;
#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
typedef unsigned char yytype_uint8;
#else
typedef short yytype_uint8;
#endif

#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
typedef __UINT_LEAST16_TYPE__ yytype_uint16;
#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST16_MAX <= INT_MAX)
typedef uint_least16_t yytype_uint16;
#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
typedef unsigned short yytype_uint16;
#else
typedef int yytype_uint16;
#endif

#ifndef YYPTRDIFF_T
# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
#  define YYPTRDIFF_T __PTRDIFF_TYPE__
#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
# elif defined PTRDIFF_MAX
#  ifndef ptrdiff_t
#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  endif
#  define YYPTRDIFF_T ptrdiff_t
#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
# else
#  define YYPTRDIFF_T long
#  define YYPTRDIFF_MAXIMUM LONG_MAX
# endif
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned
# endif
#endif

#define YYSIZE_MAXIMUM                                  \
  YY_CAST (YYPTRDIFF_T,                                 \
           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
            ? YYPTRDIFF_MAXIMUM                         \
            : YY_CAST (YYSIZE_T, -1)))

#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))


/* Stored state numbers (used for stacks). */
typedef yytype_int16 yy_state_t;

/* State numbers in computations.  */
typedef int yy_state_fast_t;

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif


#ifndef YY_ATTRIBUTE_PURE
# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
# else
#  define YY_ATTRIBUTE_PURE
# endif
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
# else
#  define YY_ATTRIBUTE_UNUSED
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YY_USE(E) ((void) (E))
#else
# define YY_USE(E) /* empty */
#endif

/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
# else
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# endif
# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
# define YY_IGNORE_USELESS_CAST_BEGIN                          \
    _Pragma ("GCC diagnostic push")                            \
    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
# define YY_IGNORE_USELESS_CAST_END            \
    _Pragma ("GCC diagnostic pop")
#endif
#ifndef YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_END
#endif


#define YY_ASSERT(E) ((void) (0 && (E)))

#if !defined yyoverflow

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* !defined yyoverflow */

#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yy_state_t yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYPTRDIFF_T yynewbytes;                                         \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYPTRDIFF_T yyi;                      \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  17
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   2045

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  158
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  138
/* YYNRULES -- Number of rules.  */
#define YYNRULES  388
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  828

/* YYMAXUTOK -- Last valid token kind.  */
#define YYMAXUTOK   389


/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, with out-of-bounds checking.  */
#define YYTRANSLATE(YYX)                                \
  (0 <= (YYX) && (YYX) <= YYMAXUTOK                     \
   ? YY_CAST (yysymbol_kind_t, yytranslate[YYX])        \
   : YYSYMBOL_YYUNDEF)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,   156,     2,     2,     2,    34,    21,     2,
      37,   152,    32,    30,   151,    31,     2,    33,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,    16,   153,
      24,    10,    25,    15,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,   154,     2,   155,    20,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,    58,    19,    59,   157,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    11,    12,    13,    14,    17,
      18,    22,    23,    26,    27,    28,    29,    35,    36,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,    51,    52,    53,    54,    55,    56,    57,    60,
      61,    62,    63,    64,    65,    66,    67,    68,    69,    70,
      71,    72,    73,    74,    75,    76,    77,    78,    79,    80,
      81,    82,    83,    84,    85,    86,    87,    88,    89,    90,
      91,    92,    93,    94,    95,    96,    97,    98,    99,   100,
     101,   102,   103,   104,   105,   106,   107,   108,   109,   110,
     111,   112,   113,   114,   115,   116,   117,   118,   119,   120,
     121,   122,   123,   124,   125,   126,   127,   128,   129,   130,
     131,   132,   133,   134,   135,   136,   137,   138,   139,   140,
     141,   142,   143,   144,   145,   146,   147,   148,   149,   150
};

#if YYDEBUG
/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_int16 yyrline[] =
{
       0,   169,   169,   170,   171,   172,   173,   177,   181,   181,
     188,   188,   201,   202,   206,   207,   208,   211,   214,   215,
     216,   218,   220,   222,   224,   226,   228,   230,   232,   234,
     236,   238,   239,   240,   242,   244,   246,   248,   250,   251,
     253,   252,   255,   257,   261,   262,   263,   267,   269,   273,
     275,   280,   281,   282,   286,   289,   292,   296,   297,   298,
     304,   303,   320,   320,   326,   327,   332,   333,   334,   335,
     336,   337,   338,   339,   340,   341,   342,   344,   346,   348,
     351,   353,   355,   357,   359,   361,   363,   362,   366,   369,
     368,   371,   375,   379,   379,   381,   383,   385,   387,   392,
     392,   397,   401,   405,   409,   412,   415,   419,   418,   424,
     423,   429,   428,   434,   435,   436,   442,   441,   458,   462,
     463,   464,   468,   470,   471,   471,   477,   484,   491,   501,
     502,   507,   515,   516,   521,   526,   531,   536,   541,   546,
     551,   558,   576,   597,   610,   619,   630,   639,   650,   659,
     668,   672,   681,   685,   693,   695,   694,   701,   702,   703,
     707,   711,   716,   717,   722,   727,   726,   734,   733,   741,
     742,   745,   747,   751,   753,   755,   757,   759,   764,   771,
     773,   777,   779,   781,   783,   785,   787,   789,   791,   796,
     796,   801,   805,   813,   817,   821,   829,   829,   833,   836,
     836,   839,   840,   845,   844,   850,   849,   855,   862,   875,
     876,   880,   881,   885,   887,   892,   897,   898,   903,   905,
     910,   914,   916,   920,   922,   928,   931,   940,   951,   951,
     955,   955,   961,   963,   965,   967,   969,   971,   974,   976,
     978,   980,   982,   984,   986,   988,   990,   992,   994,   996,
     998,  1000,  1002,  1004,  1006,  1008,  1010,  1012,  1014,  1016,
    1019,  1021,  1023,  1025,  1027,  1029,  1031,  1033,  1035,  1037,
    1039,  1041,  1042,  1041,  1051,  1053,  1055,  1057,  1059,  1061,
    1063,  1065,  1071,  1072,  1076,  1077,  1081,  1082,  1086,  1087,
    1091,  1092,  1096,  1097,  1098,  1099,  1103,  1110,  1119,  1121,
    1102,  1139,  1141,  1143,  1149,  1138,  1164,  1166,  1163,  1172,
    1171,  1179,  1180,  1181,  1182,  1183,  1184,  1185,  1186,  1190,
    1191,  1192,  1196,  1197,  1202,  1203,  1208,  1209,  1214,  1215,
    1220,  1222,  1227,  1230,  1243,  1247,  1254,  1256,  1245,  1268,
    1271,  1273,  1277,  1278,  1277,  1287,  1336,  1339,  1352,  1361,
    1364,  1371,  1371,  1383,  1384,  1388,  1392,  1401,  1401,  1415,
    1415,  1425,  1426,  1430,  1434,  1438,  1445,  1449,  1457,  1460,
    1464,  1468,  1472,  1479,  1483,  1487,  1491,  1496,  1495,  1509,
    1508,  1518,  1522,  1526,  1530,  1534,  1538,  1544,  1546
};
#endif

/** Accessing symbol of state STATE.  */
#define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])

#if YYDEBUG || 0
/* The user-facing name of the symbol whose (internal) number is
   YYSYMBOL.  No bounds checking.  */
static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;

/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "\"end of file\"", "error", "\"invalid token\"", "INT", "NAME", "LNAME",
  "PLUSEQ", "MINUSEQ", "MULTEQ", "DIVEQ", "'='", "LSHIFTEQ", "RSHIFTEQ",
  "ANDEQ", "OREQ", "'?'", "':'", "OROR", "ANDAND", "'|'", "'^'", "'&'",
  "EQ", "NE", "'<'", "'>'", "LE", "GE", "LSHIFT", "RSHIFT", "'+'", "'-'",
  "'*'", "'/'", "'%'", "UNARY", "END", "'('", "ALIGN_K", "BLOCK", "BIND",
  "QUAD", "SQUAD", "LONG", "SHORT", "BYTE", "SECTIONS", "PHDRS",
  "INSERT_K", "AFTER", "BEFORE", "DATA_SEGMENT_ALIGN",
  "DATA_SEGMENT_RELRO_END", "DATA_SEGMENT_END", "SORT_BY_NAME",
  "SORT_BY_ALIGNMENT", "SORT_NONE", "SORT_BY_INIT_PRIORITY", "'{'", "'}'",
  "SIZEOF_HEADERS", "OUTPUT_FORMAT", "FORCE_COMMON_ALLOCATION",
  "OUTPUT_ARCH", "INHIBIT_COMMON_ALLOCATION", "FORCE_GROUP_ALLOCATION",
  "SEGMENT_START", "INCLUDE", "MEMORY", "REGION_ALIAS", "LD_FEATURE",
  "NOLOAD", "DSECT", "COPY", "INFO", "OVERLAY", "READONLY", "TYPE",
  "DEFINED", "TARGET_K", "SEARCH_DIR", "MAP", "ENTRY", "NEXT", "SIZEOF",
  "ALIGNOF", "ADDR", "LOADADDR", "MAX_K", "MIN_K", "STARTUP", "HLL",
  "SYSLIB", "FLOAT", "NOFLOAT", "NOCROSSREFS", "NOCROSSREFS_TO", "ORIGIN",
  "FILL", "LENGTH", "CREATE_OBJECT_SYMBOLS", "INPUT", "GROUP", "OUTPUT",
  "CONSTRUCTORS", "ALIGNMOD", "AT", "SUBALIGN", "HIDDEN", "PROVIDE",
  "PROVIDE_HIDDEN", "AS_NEEDED", "CHIP", "LIST", "SECT", "ABSOLUTE",
  "LOAD", "NEWLINE", "ENDWORD", "ORDER", "NAMEWORD", "ASSERT_K",
  "LOG2CEIL", "FORMAT", "PUBLIC", "DEFSYMEND", "BASE", "ALIAS", "TRUNCATE",
  "REL", "INPUT_SCRIPT", "INPUT_MRI_SCRIPT", "INPUT_DEFSYM", "CASE",
  "EXTERN", "START", "VERS_TAG", "VERS_IDENTIFIER", "GLOBAL", "LOCAL",
  "VERSIONK", "INPUT_VERSION_SCRIPT", "KEEP", "ONLY_IF_RO", "ONLY_IF_RW",
  "SPECIAL", "INPUT_SECTION_FLAGS", "ALIGN_WITH_INPUT", "EXCLUDE_FILE",
  "CONSTANT", "INPUT_DYNAMIC_LIST", "','", "')'", "';'", "'['", "']'",
  "'!'", "'~'", "$accept", "file", "filename", "defsym_expr", "$@1",
  "mri_script_file", "$@2", "mri_script_lines", "mri_script_command",
  "$@3", "ordernamelist", "mri_load_name_list", "mri_abs_name_list",
  "casesymlist", "extern_name_list", "cond_extern_name_list", "@4",
  "script_file", "$@5", "ifile_list", "ifile_p1", "$@6", "$@7", "$@8",
  "input_list", "$@9", "input_list1", "@10", "@11", "@12",
  "cond_input_list", "@13", "sections", "sec_or_group_p1",
  "statement_anywhere", "$@14", "wildcard_name", "wildcard_maybe_exclude",
  "filename_spec", "section_name_spec", "sect_flag_list", "sect_flags",
  "exclude_name_list", "section_name_list", "input_section_spec_no_keep",
  "input_section_spec", "$@15", "statement", "$@16", "$@17",
  "statement_list", "statement_list_opt", "length", "fill_exp", "fill_opt",
  "assign_op", "separator", "assignment", "opt_comma", "memory",
  "memory_spec_list_opt", "memory_spec_list", "memory_spec", "$@18",
  "$@19", "origin_spec", "length_spec", "attributes_opt",
  "attributes_list", "attributes_string", "startup", "high_level_library",
  "high_level_library_NAME_list", "low_level_library",
  "low_level_library_NAME_list", "floating_point_support",
  "nocrossref_list", "paren_script_name", "$@20", "mustbe_exp", "$@21",
  "exp", "$@22", "$@23", "memspec_at_opt", "opt_at", "opt_align",
  "opt_align_with_input", "opt_subalign", "sect_constraint", "section",
  "$@24", "$@25", "$@26", "$@27", "$@28", "$@29", "$@30", "$@31", "$@32",
  "$@33", "$@34", "type", "atype", "opt_exp_with_type",
  "opt_exp_without_type", "opt_nocrossrefs", "memspec_opt", "phdr_opt",
  "overlay_section", "$@35", "$@36", "$@37", "phdrs", "phdr_list", "phdr",
  "$@38", "$@39", "phdr_type", "phdr_qualifiers", "phdr_val",
  "dynamic_list_file", "$@40", "dynamic_list_nodes", "dynamic_list_node",
  "dynamic_list_tag", "version_script_file", "$@41", "version", "$@42",
  "vers_nodes", "vers_node", "verdep", "vers_tag", "vers_defns", "@43",
  "@44", "opt_semicolon", YY_NULLPTR
};

static const char *
yysymbol_name (yysymbol_kind_t yysymbol)
{
  return yytname[yysymbol];
}
#endif

#define YYPACT_NINF (-759)

#define yypact_value_is_default(Yyn) \
  ((Yyn) == YYPACT_NINF)

#define YYTABLE_NINF (-360)

#define yytable_value_is_error(Yyn) \
  0

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
static const yytype_int16 yypact[] =
{
     187,  -759,  -759,  -759,  -759,  -759,    28,  -759,  -759,  -759,
    -759,  -759,   149,  -759,   -24,  -759,    -1,  -759,   906,  1754,
     952,    47,    63,   102,  -759,    20,     7,   -24,  -759,   117,
      -1,  -759,    66,   186,   203,   247,  -759,   254,  -759,  -759,
     289,   258,   290,   298,   301,   305,   307,   308,   309,   310,
     311,  -759,  -759,   314,   317,   318,  -759,   320,  -759,   323,
    -759,  -759,  -759,  -759,   -34,  -759,  -759,  -759,  -759,  -759,
    -759,  -759,   221,  -759,   358,   289,   359,   786,  -759,   360,
     362,   366,  -759,  -759,   367,   368,   369,   786,   370,   372,
     374,    44,   375,   263,  -759,  -759,  -759,  -759,  -759,  -759,
    -759,  -759,  -759,  -759,   377,   383,   384,  -759,   386,  -759,
     385,   388,   332,   229,    20,  -759,  -759,  -759,   341,   252,
    -759,  -759,  -759,   403,   405,   406,   407,  -759,  -759,    22,
     409,   411,   413,   289,   289,   414,   289,    23,  -759,   419,
     419,  -759,   391,   289,   410,  -759,  -759,  -759,  -759,   390,
      75,  -759,    92,  -759,  -759,   786,   786,   786,   420,   421,
     422,   423,   425,  -759,  -759,   426,   427,  -759,  -759,  -759,
    -759,   428,   434,  -759,  -759,   453,   454,   456,   457,   786,
     786,   455,   346,  -759,   293,  -759,   295,    40,  -759,  -759,
     524,  1965,   345,  -759,  -759,   348,  -759,  -759,    16,  -759,
    -759,  -759,  -759,   786,  -759,   446,   482,   490,   443,   117,
     117,   351,   282,   447,   352,   282,   462,    33,  -759,  -759,
     144,   357,  -759,  -759,   289,   451,    -3,  -759,   361,   364,
     371,   373,   379,   380,   381,  -759,  -759,   153,   155,    79,
     387,   389,   393,    36,  -759,   394,   786,    44,   -24,   786,
     786,  -759,   786,   786,  -759,  -759,  1126,   786,   786,   786,
     786,   786,   476,   514,   786,  -759,   483,  -759,  -759,  -759,
     786,   786,  -759,  -759,   786,   786,   786,   518,  -759,  -759,
     786,   786,   786,   786,   786,   786,   786,   786,   786,   786,
     786,   786,   786,   786,   786,   786,   786,   786,   786,   786,
     786,   786,  1965,   520,   522,  -759,   532,   786,   786,  1965,
     326,   534,   526,  -759,    73,  -759,  1965,  -759,  -759,  -759,
    -759,   395,   396,  -759,  -759,   536,  -759,  -759,  -759,  -101,
    -759,   952,  -759,   289,  -759,  -759,  -759,  -759,  -759,  -759,
    -759,   539,  -759,  -759,   987,   510,  -759,  -759,  -759,    22,
     547,  -759,  -759,  -759,  -759,  -759,  -759,  -759,   289,  -759,
     289,   419,  -759,  -759,  -759,  -759,  -759,  -759,  -759,   515,
     126,  -759,   404,  -759,   894,    95,   -27,  1965,  1965,  1790,
    1965,  1965,  -759,  1105,  1146,  1651,  1671,  1166,   553,   416,
    1186,   554,  1691,  1711,  1206,  1750,  1243,   417,  1991,  1261,
    1358,  1221,  1414,  1491,   715,   715,   408,   408,   408,   408,
     268,   268,   239,   239,  -759,  -759,  -759,  1965,  1965,  1965,
    -759,  -759,  -759,  1965,  1965,  -759,  -759,  -759,  -759,  -759,
    -759,   429,   430,   433,   117,   288,   282,   502,  -759,  -759,
     -77,   612,  -759,   699,   612,   786,   415,  -759,    15,   549,
      22,  -759,   435,  -759,  -759,  -759,   557,  -759,  -759,  -759,
     537,    38,  -759,  -759,   574,  -759,  -759,  -759,   786,  -759,
    -759,   786,   786,  -759,  -759,  -759,  -759,   436,   786,   786,
    -759,   575,  -759,  -759,   786,    44,  -759,  -759,  -759,   438,
     564,  -759,  -759,  -759,   237,   552,  1944,   576,   487,  -759,
    -759,  2011,   499,  -759,  1965,    17,   591,  -759,   592,    13,
    -759,   500,   563,  -759,  -759,    36,  -759,  -759,  -759,   567,
    -759,   449,  1282,  1302,  1322,   466,  -759,  1342,  1379,   467,
    1965,    97,   282,   546,   117,   117,  -759,  -759,  -759,  -759,
    -759,   581,   614,  -759,   468,   786,   378,   606,  -759,   588,
     589,   724,  -759,  -759,   487,   568,   601,   603,  -759,   489,
    -759,  -759,  -759,   634,   496,  -759,    36,    41,    36,  -759,
    -759,  -759,  -759,  -759,   786,  -759,  -759,  -759,  -759,  -759,
     501,   438,   578,   786,  -759,  1399,  -759,   786,   619,   511,
    -759,   550,  -759,   786,    17,   786,   506,  -759,  -759,   562,
      45,  -759,    50,    36,  1438,   282,   607,   652,  1965,   224,
    1458,   786,  -759,   550,   630,  -759,   610,  1478,  -759,  1515,
    -759,  -759,   658,  -759,  -759,  -759,   131,  -759,  -759,   786,
     633,   655,  -759,  1535,   136,   786,   616,  -759,  -759,    17,
    -759,  -759,  1555,   786,  -759,  -759,  -759,  -759,  -759,  -759,
    1594,  -759,  -759,  -759,  -759,  1614,   621,  -759,  -759,   645,
     836,    34,   667,   623,  -759,  -759,  -759,  -759,  -759,   647,
     649,   289,   650,  -759,  -759,  -759,   651,   654,   656,  -759,
      86,  -759,  -759,   657,    32,  -759,  -759,  -759,   836,   646,
     669,   -34,  -759,   664,  -759,   146,    87,  -759,  -759,   670,
    -759,   700,   704,  -759,   673,   676,   679,   680,  -759,  -759,
     -89,    86,   684,   685,    86,   686,  -759,  -759,  -759,  -759,
     666,   721,   620,   580,   602,   604,   836,   605,  -759,   786,
      18,  -759,     8,  -759,    26,    14,    91,    87,    87,  -759,
      86,   181,    87,   -18,    86,   664,   611,   836,  -759,   728,
    -759,  -759,  -759,  -759,   719,  -759,  1786,   615,   618,   754,
    -759,   704,  -759,   725,   727,   622,   729,   734,   624,   626,
     627,  -759,  -759,  -759,   188,   620,  -759,   713,   769,   112,
    -759,   771,  -759,  -759,  -759,    87,    87,  -759,    87,    87,
    -759,  -759,  -759,  -759,  -759,  -759,  -759,  -759,   776,  -759,
     629,   640,   641,   642,   643,   112,  -759,  -759,  -759,   496,
     -34,   648,   653,   659,   660,  -759,   112,  -759,  -759,  -759,
    -759,  -759,  -759,   496,  -759,  -759,   496,  -759
};

/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE does not specify something else to do.  Zero
   means the default is an error.  */
static const yytype_int16 yydefact[] =
{
       0,    62,    10,     8,   357,   351,     0,     2,    65,     3,
      13,     6,     0,     4,     0,     5,     0,     1,    63,    11,
       0,     0,     0,     0,     9,   368,     0,   358,   361,     0,
     352,   353,     0,     0,     0,     0,    82,     0,    84,    83,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   223,   224,     0,     0,     0,    86,     0,   124,     0,
      75,    64,    67,    73,     0,    66,    69,    70,    71,    72,
      68,    74,     0,    16,     0,     0,     0,     0,    17,     0,
       0,     0,    19,    46,     0,     0,     0,     0,     0,     0,
      51,     0,     0,     0,   181,   182,   183,   184,   230,   185,
     186,   187,   188,   230,     0,     0,     0,   374,   385,   373,
     381,   383,     0,     0,   368,   362,   381,   383,     0,     0,
     354,   121,   340,     0,     0,     0,     0,     7,    89,   200,
       0,     0,     0,     0,     0,     0,     0,     0,   222,   225,
     225,    99,     0,     0,     0,    93,   190,   189,   123,     0,
       0,    40,     0,   258,   275,     0,     0,     0,     0,     0,
       0,     0,     0,   259,   271,     0,     0,   228,   228,   228,
     228,     0,     0,   228,   228,     0,     0,     0,     0,     0,
       0,    14,     0,    49,    31,    47,    32,    18,    33,    23,
       0,    36,     0,    37,    52,    38,    54,   230,    39,    57,
      42,    12,   191,     0,   192,     0,     0,     0,     0,     0,
       0,     0,   369,     0,     0,   356,     0,     0,    95,    96,
       0,     0,    65,   203,     0,     0,   197,   202,     0,     0,
       0,     0,     0,     0,     0,   217,   219,   197,   197,   225,
       0,     0,     0,     0,    99,     0,     0,     0,     0,     0,
       0,    13,     0,     0,   236,   232,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   261,     0,   260,   262,   263,
       0,     0,   279,   280,     0,     0,     0,     0,   235,   237,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,    25,     0,     0,    45,     0,     0,     0,    22,
       0,     0,     0,    55,     0,    58,   231,   230,   230,   230,
     379,     0,     0,   363,   376,   386,   375,   382,   384,     0,
     355,   296,   118,     0,   301,   306,   120,   119,   342,   339,
     341,     0,    79,    81,   359,   209,   205,   198,   196,     0,
       0,    98,    76,    77,    88,   122,   215,   216,     0,   220,
       0,   225,   226,    91,    92,    85,   101,   104,   230,     0,
     100,   113,     0,    78,     0,     0,     0,    27,    28,    43,
      29,    30,   233,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   256,
     255,   253,   252,   251,   245,   246,   249,   250,   247,   248,
     243,   244,   241,   242,   238,   239,   240,    15,    26,    24,
      50,    48,    44,    20,    21,    35,    34,    53,    60,    56,
      59,     0,     0,     0,     0,   370,   371,     0,   366,   364,
       0,   320,   309,     0,   320,     0,     0,    90,     0,     0,
     200,   201,     0,   218,   221,   227,     0,   107,   103,   106,
       0,     0,   115,    87,     0,    94,   360,    41,     0,   266,
     274,     0,     0,   270,   272,   257,   234,     0,     0,     0,
     265,     0,   281,   264,     0,     0,   193,   194,   195,   387,
     384,   377,   367,   365,     0,     0,   320,     0,   285,   121,
     327,     0,   328,   307,   345,   346,     0,   213,     0,     0,
     211,     0,     0,    97,   116,     0,   111,   102,   105,     0,
     114,     0,     0,     0,     0,     0,   229,     0,     0,     0,
     254,     0,   388,     0,     0,     0,   311,   312,   313,   314,
     315,   317,     0,   321,     0,     0,     0,     0,   323,     0,
     287,     0,   326,   329,   285,     0,   349,     0,   343,     0,
     214,   210,   212,     0,   197,   206,     0,     0,     0,   109,
     125,   267,   268,   269,     0,   276,   277,   278,    61,   380,
       0,   387,     0,     0,   319,     0,   322,     0,     0,   289,
     310,   291,   121,     0,   346,     0,     0,    80,   230,     0,
       0,   108,     0,     0,     0,   372,     0,     0,   318,   320,
       0,     0,   288,   291,     0,   302,     0,     0,   347,     0,
     344,   207,     0,   204,   117,   112,     0,   273,   378,     0,
       0,     0,   284,     0,   295,     0,     0,   308,   350,   346,
     230,   110,     0,     0,   324,   286,   292,   293,   294,   297,
       0,   303,   348,   208,   316,     0,     0,   290,   334,   320,
     171,     0,     0,   148,   173,   174,   175,   176,   177,     0,
       0,     0,     0,   159,   160,   165,     0,     0,     0,   157,
       0,   127,   129,     0,     0,   154,   162,   170,   172,     0,
       0,     0,   335,   331,   325,     0,     0,   167,   230,     0,
     155,     0,     0,   126,     0,     0,     0,     0,   132,   147,
     197,     0,   149,     0,     0,     0,   169,   298,   230,   158,
       0,     0,   283,     0,     0,     0,   171,     0,   178,     0,
       0,   141,     0,   145,     0,     0,     0,     0,     0,   150,
       0,   197,     0,   197,     0,   331,     0,   171,   330,     0,
     332,   161,   130,   131,     0,   164,     0,   126,     0,     0,
     143,     0,   144,     0,     0,     0,     0,     0,     0,     0,
       0,   146,   152,   151,   197,   283,   163,     0,     0,   180,
     168,     0,   156,   142,   128,     0,     0,   133,     0,     0,
     134,   135,   140,   153,   332,   336,   282,   230,     0,   304,
       0,     0,     0,     0,     0,   180,   332,   179,   333,   197,
       0,     0,     0,     0,     0,   299,   180,   305,   166,   137,
     136,   138,   139,   197,   337,   300,   197,   338
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -759,  -759,   -73,  -759,  -759,  -759,  -759,   551,  -759,  -759,
    -759,  -759,  -759,  -759,  -240,  -188,  -759,  -759,  -759,   579,
    -759,  -759,  -759,  -759,   559,  -759,  -448,  -759,  -759,  -759,
    -364,  -759,  -759,  -476,   -13,  -759,  -663,  1216,   113,    64,
    -759,  -759,  -759,  -606,    77,  -759,  -759,   120,  -759,  -759,
    -759,  -632,  -759,    12,  -758,  -759,  -666,   -12,  -223,  -759,
     363,  -759,   461,  -759,  -759,  -759,  -759,  -759,  -759,   306,
    -759,  -759,  -759,  -759,  -759,  -759,  -128,    96,  -759,   -90,
    -759,   -76,  -759,  -759,    43,   265,  -759,  -759,   209,  -759,
    -759,  -759,  -759,  -759,  -759,  -759,  -759,  -759,  -759,  -759,
    -759,  -759,  -759,  -480,   392,  -759,  -759,    82,  -681,  -759,
    -759,  -759,  -759,  -759,  -759,  -759,  -759,  -759,  -759,  -543,
    -759,  -759,  -759,  -759,   798,  -759,  -759,  -759,  -759,  -759,
     582,   -23,  -759,   717,   -20,  -759,  -759,   248
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
       0,     6,   128,    11,    12,     9,    10,    19,    93,   251,
     187,   186,   184,   195,   198,   199,   485,     7,     8,    18,
      61,   142,   222,   247,   242,   243,   370,   515,   603,   568,
     371,   566,    62,   216,   336,   144,   681,   682,   683,   709,
     732,   684,   734,   710,   685,   686,   730,   687,   699,   726,
     688,   689,   690,   727,   799,   103,   148,    64,   740,    65,
     225,   226,   227,   345,   450,   564,   623,   449,   509,   510,
      66,    67,   237,    68,   238,    69,   240,   265,   266,   728,
     203,   256,   262,   525,   750,   550,   589,   613,   615,   649,
     337,   441,   656,   745,   823,   443,   636,   658,   809,   444,
     555,   499,   544,   497,   498,   502,   554,   722,   779,   661,
     720,   806,   826,    70,   217,   340,   445,   596,   505,   558,
     594,    15,    16,    30,    31,   118,    13,    14,    71,    72,
      27,    28,   440,   112,   113,   535,   434,   533
};

/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule whose
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
      24,   181,   151,   349,   115,    63,   462,   375,   202,   119,
     315,   191,   241,   204,   358,   360,   547,   507,   703,   507,
     313,   556,   757,   551,   107,   719,   223,   127,    17,   759,
     703,    25,   466,  -199,    25,   438,   712,   338,   692,   733,
     366,   367,   517,   518,   305,   458,   459,   815,   196,   458,
     459,   618,   439,   197,   458,   459,  -199,    29,   824,   492,
     231,   232,   348,   234,   236,   114,   739,   567,   763,   764,
     245,   762,   713,   368,   670,   368,   493,   429,   368,   254,
     255,   197,   368,   239,   104,   249,   713,   368,   670,   224,
     703,   703,   339,   693,   754,   703,   652,   520,   784,   313,
     105,   313,   252,   278,   279,   741,   302,   312,   743,    26,
     197,   362,    26,   805,   309,   777,   616,   146,   600,   147,
     602,   107,   797,   557,   121,   816,   430,   316,   798,   631,
     458,   459,   197,   348,   197,   458,   459,   773,   774,   106,
     704,   705,   706,   707,   818,   766,   767,   369,   348,   519,
     703,   346,   460,    20,   108,   626,   460,   109,   110,   111,
     760,   460,   678,   368,   677,   561,   678,   314,   368,   508,
     374,   508,   680,   377,   378,   235,   380,   381,   761,   662,
     678,   383,   384,   385,   386,   387,   714,   315,   390,   321,
     322,   306,   461,   601,   392,   393,   461,   624,   394,   395,
     396,   461,   625,   462,   398,   399,   400,   401,   402,   403,
     404,   405,   406,   407,   408,   409,   410,   411,   412,   413,
     414,   415,   416,   417,   418,   419,   250,   431,   432,   433,
     361,   423,   424,   455,   678,   678,   462,   460,   462,   678,
     153,   154,   460,   253,   122,   531,   314,   465,   314,   578,
     723,   108,   123,   124,   109,   116,   117,    21,    22,    23,
     442,   546,   462,   630,   267,   268,   269,   155,   156,   272,
     273,   296,   297,   298,   157,   158,   159,   461,   456,   646,
     647,   648,   461,   641,   125,   453,   324,   454,   160,   161,
     162,   126,   324,   127,   678,   341,   342,   163,   294,   295,
     296,   297,   298,   164,   348,   357,   348,   359,   536,   537,
     538,   539,   540,   541,   542,   165,   129,     1,     2,     3,
     166,   167,   168,   169,   170,   171,   172,   130,     4,   425,
     426,    63,   348,   772,   173,   131,   174,     5,   132,   348,
     793,   599,   133,   315,   134,   135,   136,   137,   138,   153,
     154,   139,   175,   115,   140,   141,   300,   143,   176,   177,
     145,   149,   150,   152,   182,   496,   183,   501,   496,   504,
     185,   188,   189,   190,   192,   193,   155,   156,   194,   200,
     201,   205,   212,   157,   158,   159,   178,   206,   207,   543,
     208,   211,   522,   179,   180,   523,   524,   160,   161,   162,
     214,   209,   527,   528,   210,   215,   163,   218,   530,   219,
     220,   221,   164,   228,   489,   229,   325,   230,   233,   326,
     327,   328,   325,   239,   165,   326,   327,   490,   244,   166,
     167,   168,   169,   170,   171,   172,   292,   293,   294,   295,
     296,   297,   298,   173,   303,   174,   304,   246,   248,   536,
     537,   538,   539,   540,   541,   542,   317,   257,   258,   259,
     260,   175,   261,   263,   264,   270,   331,   176,   177,   585,
     280,   271,   281,   282,   283,   284,   285,   286,   287,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
     274,   275,   318,   276,   277,   178,   310,   301,   604,   311,
     319,   320,   179,   180,   323,   330,   329,   608,   621,   343,
     347,   610,   350,   388,   580,   581,   351,   617,   389,   619,
     391,   332,   397,   352,   420,   353,   421,   153,   154,   333,
     543,   354,   355,   356,   307,   633,   422,   334,   427,   363,
     437,   364,   428,   446,    47,   365,   373,   448,   435,   436,
     653,   452,   457,   642,   155,   156,   463,   474,   477,   650,
     491,   157,   158,   159,   335,   511,   506,   655,   475,   483,
      21,    22,    23,   514,   516,   160,   161,   162,   521,   529,
     534,   486,   487,    58,   163,   488,   817,   513,   526,   545,
     164,   532,   548,   549,   553,   559,   560,   563,   697,   565,
     825,   570,   165,   827,   569,   579,   299,   166,   167,   168,
     169,   170,   171,   172,   331,   153,   154,   574,   582,   577,
     584,   173,   586,   174,   583,   587,   592,   588,   746,    94,
      95,    96,    97,    98,    99,   100,   101,   102,   593,   175,
     595,   597,   155,   156,   598,   176,   177,   348,   691,   494,
     158,   159,   495,   756,   605,   607,   611,   614,   612,   620,
    -126,   622,   629,   160,   161,   162,   628,   635,   640,   637,
     643,   644,   163,   178,   651,   308,   691,   333,   164,   660,
     179,   180,   546,   694,   695,   334,   696,   698,   700,   721,
     165,   701,    47,   702,   711,   166,   167,   168,   169,   170,
     171,   172,   153,   154,   731,   717,   718,   729,   703,   173,
     735,   174,   335,   736,   691,   500,   737,   738,    21,    22,
      23,  -126,   742,   744,   747,   748,   749,   175,   331,   155,
     156,    58,   751,   176,   177,   691,   157,   158,   159,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
     160,   161,   162,   778,   752,   780,   753,   755,   783,   163,
     590,   178,   785,   776,   786,   164,   788,  -148,   179,   180,
     782,   789,   795,   796,   787,   800,   790,   165,   791,   792,
     808,   810,   166,   167,   168,   169,   170,   171,   172,   153,
     154,   333,   811,   812,   813,   814,   173,   715,   174,   334,
     819,   344,   379,   372,   771,   820,    47,   758,   716,   807,
     451,   821,   822,   512,   175,   562,   155,   156,   794,   591,
     176,   177,   634,   157,   158,   159,   335,   775,   120,   606,
     376,   213,    21,    22,    23,     0,   503,   160,   161,   162,
     663,     0,     0,     0,     0,    58,   163,     0,   178,     0,
       0,     0,   164,     0,     0,   179,   180,     0,     0,     0,
       0,     0,     0,     0,   165,     0,     0,     0,     0,   166,
     167,   168,   169,   170,   171,   172,     0,   664,   665,   666,
     667,   668,     0,   173,     0,   174,     0,     0,     0,     0,
     669,     0,   670,     0,     0,     0,     0,     0,     0,     0,
       0,   175,     0,   671,     0,     0,     0,   176,   177,   280,
      20,   281,   282,   283,   284,   285,   286,   287,   288,   289,
     290,   291,   292,   293,   294,   295,   296,   297,   298,     0,
       0,     0,     0,     0,   672,   178,   673,     0,     0,     0,
     674,     0,   179,   180,    21,    22,    23,     0,     0,     0,
       0,     0,    32,    33,    34,     0,     0,   675,    94,    95,
      96,    97,    98,    99,   100,   101,   102,    35,    36,    37,
      38,    39,     0,    40,    41,    42,    43,     0,   676,     0,
       0,     0,   677,     0,   678,    44,    45,    46,    47,   679,
     680,    20,     0,     0,     0,     0,    48,    49,    50,    51,
      52,    53,    54,     0,     0,     0,     0,    55,    56,    57,
       0,     0,     0,     0,    21,    22,    23,     0,     0,     0,
       0,     0,     0,   447,     0,     0,     0,    58,     0,     0,
       0,     0,     0,    32,    33,    34,     0,     0,     0,     0,
      59,     0,     0,     0,     0,   464,  -359,     0,    35,    36,
      37,    38,    39,     0,    40,    41,    42,    43,     0,    60,
       0,     0,     0,     0,     0,     0,    44,    45,    46,    47,
       0,     0,     0,     0,     0,     0,     0,    48,    49,    50,
      51,    52,    53,    54,     0,     0,     0,     0,    55,    56,
      57,     0,     0,     0,     0,    21,    22,    23,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    58,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     280,    59,   281,   282,   283,   284,   285,   286,   287,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
      60,   280,     0,   281,   282,   283,   284,   285,   286,   287,
     288,   289,   290,   291,   292,   293,   294,   295,   296,   297,
     298,   280,     0,   281,   282,   283,   284,   285,   286,   287,
     288,   289,   290,   291,   292,   293,   294,   295,   296,   297,
     298,   280,     0,   281,   282,   283,   284,   285,   286,   287,
     288,   289,   290,   291,   292,   293,   294,   295,   296,   297,
     298,   280,     0,   281,   282,   283,   284,   285,   286,   287,
     288,   289,   290,   291,   292,   293,   294,   295,   296,   297,
     298,   280,     0,   281,   282,   283,   284,   285,   286,   287,
     288,   289,   290,   291,   292,   293,   294,   295,   296,   297,
     298,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,   468,   469,   280,     0,
     281,   282,   283,   284,   285,   286,   287,   288,   289,   290,
     291,   292,   293,   294,   295,   296,   297,   298,   382,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,     0,   280,   470,   281,
     282,   283,   284,   285,   286,   287,   288,   289,   290,   291,
     292,   293,   294,   295,   296,   297,   298,   280,   473,   281,
     282,   283,   284,   285,   286,   287,   288,   289,   290,   291,
     292,   293,   294,   295,   296,   297,   298,   280,   476,   281,
     282,   283,   284,   285,   286,   287,   288,   289,   290,   291,
     292,   293,   294,   295,   296,   297,   298,   280,   480,   281,
     282,   283,   284,   285,   286,   287,   288,   289,   290,   291,
     292,   293,   294,   295,   296,   297,   298,   283,   284,   285,
     286,   287,   288,   289,   290,   291,   292,   293,   294,   295,
     296,   297,   298,     0,   280,   482,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   280,     0,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   571,   285,   286,   287,   288,   289,
     290,   291,   292,   293,   294,   295,   296,   297,   298,     0,
       0,     0,     0,   280,   572,   281,   282,   283,   284,   285,
     286,   287,   288,   289,   290,   291,   292,   293,   294,   295,
     296,   297,   298,   280,   573,   281,   282,   283,   284,   285,
     286,   287,   288,   289,   290,   291,   292,   293,   294,   295,
     296,   297,   298,   280,   575,   281,   282,   283,   284,   285,
     286,   287,   288,   289,   290,   291,   292,   293,   294,   295,
     296,   297,   298,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,     0,     0,     0,     0,
     280,   576,   281,   282,   283,   284,   285,   286,   287,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
     280,   609,   281,   282,   283,   284,   285,   286,   287,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
     280,     0,   281,   282,   283,   284,   285,   286,   287,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
     627,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   280,
     632,   281,   282,   283,   284,   285,   286,   287,   288,   289,
     290,   291,   292,   293,   294,   295,   296,   297,   298,   280,
     638,   281,   282,   283,   284,   285,   286,   287,   288,   289,
     290,   291,   292,   293,   294,   295,   296,   297,   298,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   280,   639,   281,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,   280,   645,   281,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,   280,   654,   281,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,   280,     0,   281,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,   657,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    73,     0,
       0,     0,     0,     0,     0,   280,   659,   281,   282,   283,
     284,   285,   286,   287,   288,   289,   290,   291,   292,   293,
     294,   295,   296,   297,   298,     0,     0,     0,     0,     0,
       0,     0,    74,     0,    73,     0,     0,     0,     0,     0,
       0,   280,   471,   281,   282,   283,   284,   285,   286,   287,
     288,   289,   290,   291,   292,   293,   294,   295,   296,   297,
     298,    75,   472,     0,     0,     0,   467,     0,    74,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   478,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    75,     0,    76,
       0,     0,   479,     0,     0,     0,    77,    78,    79,    80,
      81,   -43,    82,    83,    84,     0,     0,    85,    86,     0,
      87,    88,    89,     0,     0,     0,     0,    90,    91,    92,
       0,     0,     0,     0,     0,    76,   708,     0,     0,     0,
       0,   481,    77,    78,    79,    80,    81,     0,    82,    83,
      84,   724,   725,    85,    86,     0,    87,    88,    89,     0,
       0,     0,     0,    90,    91,    92,     0,   708,     0,     0,
     708,     0,     0,     0,     0,     0,     0,   781,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   765,   768,   769,   770,     0,   708,     0,   724,   280,
     708,   281,   282,   283,   284,   285,   286,   287,   288,   289,
     290,   291,   292,   293,   294,   295,   296,   297,   298,     0,
     280,   546,   281,   282,   283,   284,   285,   286,   287,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
       0,   801,   802,     0,   803,   804,   280,   484,   281,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,   280,   552,   281,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298
};

static const yytype_int16 yycheck[] =
{
      12,    77,    75,   226,    27,    18,   370,   247,    98,    29,
     198,    87,   140,   103,   237,   238,   496,     4,     4,     4,
       4,     4,     4,   499,     4,   691,     4,     4,     0,    21,
       4,    58,    59,    36,    58,   136,     4,     4,     4,   702,
       4,     5,     4,     5,     4,     4,     5,   805,     4,     4,
       5,   594,   153,    37,     4,     5,    59,    58,   816,   136,
     133,   134,   151,   136,   137,    58,   155,   515,    54,    55,
     143,   734,    54,    37,    56,    37,   153,     4,    37,   155,
     156,    37,    37,     4,    37,    10,    54,    37,    56,    67,
       4,     4,    59,    59,   726,     4,   639,   461,   761,     4,
      37,     4,    10,   179,   180,   711,   182,   197,   714,   136,
      37,   239,   136,   794,   190,   747,   592,   151,   566,   153,
     568,     4,    10,   106,    58,   806,   314,   203,    16,   609,
       4,     5,    37,   151,    37,     4,     5,   155,   744,    37,
      54,    55,    56,    57,   810,    54,    55,   111,   151,   111,
       4,   224,   111,     4,   134,   603,   111,   137,   138,   139,
     152,   111,   148,    37,   146,   152,   148,   151,    37,   156,
     246,   156,   154,   249,   250,   152,   252,   253,   152,   659,
     148,   257,   258,   259,   260,   261,   154,   375,   264,   209,
     210,   151,   151,   152,   270,   271,   151,   152,   274,   275,
     276,   151,   152,   567,   280,   281,   282,   283,   284,   285,
     286,   287,   288,   289,   290,   291,   292,   293,   294,   295,
     296,   297,   298,   299,   300,   301,   151,   317,   318,   319,
     151,   307,   308,   361,   148,   148,   600,   111,   602,   148,
       3,     4,   111,   151,    58,   485,   151,   152,   151,   152,
     104,   134,    49,    50,   137,   138,   139,   108,   109,   110,
     333,    37,   626,    39,   168,   169,   170,    30,    31,   173,
     174,    32,    33,    34,    37,    38,    39,   151,   368,   143,
     144,   145,   151,   152,    37,   358,     4,   360,    51,    52,
      53,    37,     4,     4,   148,   151,   152,    60,    30,    31,
      32,    33,    34,    66,   151,   152,   151,   152,    71,    72,
      73,    74,    75,    76,    77,    78,    58,   130,   131,   132,
      83,    84,    85,    86,    87,    88,    89,    37,   141,     3,
       4,   344,   151,   152,    97,    37,    99,   150,    37,   151,
     152,   564,    37,   531,    37,    37,    37,    37,    37,     3,
       4,    37,   115,   376,    37,    37,    10,    37,   121,   122,
      37,   140,     4,     4,     4,   441,     4,   443,   444,   445,
       4,     4,     4,     4,     4,     3,    30,    31,     4,     4,
     117,     4,   153,    37,    38,    39,   149,     4,     4,   152,
       4,    59,   468,   156,   157,   471,   472,    51,    52,    53,
      59,    16,   478,   479,    16,   153,    60,     4,   484,     4,
       4,     4,    66,     4,   434,     4,   134,     4,     4,   137,
     138,   139,   134,     4,    78,   137,   138,   139,    37,    83,
      84,    85,    86,    87,    88,    89,    28,    29,    30,    31,
      32,    33,    34,    97,   151,    99,   151,    37,    58,    71,
      72,    73,    74,    75,    76,    77,    10,    37,    37,    37,
      37,   115,    37,    37,    37,    37,     4,   121,   122,   545,
      15,    37,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      37,    37,    10,    37,    37,   149,   151,   151,   574,   151,
      10,    58,   156,   157,   153,   153,    59,   583,   598,   152,
      59,   587,   151,    37,   534,   535,   152,   593,     4,   595,
      37,    59,     4,   152,     4,   152,     4,     3,     4,    67,
     152,   152,   152,   152,    10,   611,     4,    75,     4,   152,
       4,   152,    16,     4,    82,   152,   152,    37,   153,   153,
     640,     4,    37,   629,    30,    31,   152,     4,     4,   635,
      58,    37,    38,    39,   102,    16,   151,   643,   152,   152,
     108,   109,   110,    16,    37,    51,    52,    53,     4,     4,
      16,   152,   152,   121,    60,   152,   809,   152,   152,    37,
      66,   153,    16,   106,    95,     4,     4,    97,   671,    36,
     823,   152,    78,   826,    37,    59,   151,    83,    84,    85,
      86,    87,    88,    89,     4,     3,     4,   151,    37,   152,
     152,    97,    16,    99,    10,    37,    58,    38,   718,     6,
       7,     8,     9,    10,    11,    12,    13,    14,    37,   115,
      37,   152,    30,    31,    10,   121,   122,   151,   660,    37,
      38,    39,    40,   729,   153,    77,    37,   107,   147,   153,
      37,    99,    10,    51,    52,    53,    59,    37,    10,    59,
      37,    16,    60,   149,    58,   151,   688,    67,    66,    58,
     156,   157,    37,    16,    37,    75,    37,    37,    37,    25,
      78,    37,    82,    37,    37,    83,    84,    85,    86,    87,
      88,    89,     3,     4,     4,    59,    37,    37,     4,    97,
      37,    99,   102,    37,   726,    16,    37,    37,   108,   109,
     110,    37,    37,    37,    58,     4,   106,   115,     4,    30,
      31,   121,   152,   121,   122,   747,    37,    38,    39,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      51,    52,    53,    25,   152,    36,   152,   152,     4,    60,
      36,   149,    37,   152,    37,    66,    37,   152,   156,   157,
     152,    37,    59,     4,   152,     4,   152,    78,   152,   152,
       4,   152,    83,    84,    85,    86,    87,    88,    89,     3,
       4,    67,   152,   152,   152,   152,    97,   684,    99,    75,
     152,   222,   251,   244,   740,   152,    82,   730,   688,   797,
     349,   152,   152,   450,   115,   509,    30,    31,   775,   554,
     121,   122,   613,    37,    38,    39,   102,   745,    30,   581,
     248,   114,   108,   109,   110,    -1,   444,    51,    52,    53,
       4,    -1,    -1,    -1,    -1,   121,    60,    -1,   149,    -1,
      -1,    -1,    66,    -1,    -1,   156,   157,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    78,    -1,    -1,    -1,    -1,    83,
      84,    85,    86,    87,    88,    89,    -1,    41,    42,    43,
      44,    45,    -1,    97,    -1,    99,    -1,    -1,    -1,    -1,
      54,    -1,    56,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   115,    -1,    67,    -1,    -1,    -1,   121,   122,    15,
       4,    17,    18,    19,    20,    21,    22,    23,    24,    25,
      26,    27,    28,    29,    30,    31,    32,    33,    34,    -1,
      -1,    -1,    -1,    -1,    98,   149,   100,    -1,    -1,    -1,
     104,    -1,   156,   157,   108,   109,   110,    -1,    -1,    -1,
      -1,    -1,    46,    47,    48,    -1,    -1,   121,     6,     7,
       8,     9,    10,    11,    12,    13,    14,    61,    62,    63,
      64,    65,    -1,    67,    68,    69,    70,    -1,   142,    -1,
      -1,    -1,   146,    -1,   148,    79,    80,    81,    82,   153,
     154,     4,    -1,    -1,    -1,    -1,    90,    91,    92,    93,
      94,    95,    96,    -1,    -1,    -1,    -1,   101,   102,   103,
      -1,    -1,    -1,    -1,   108,   109,   110,    -1,    -1,    -1,
      -1,    -1,    -1,    36,    -1,    -1,    -1,   121,    -1,    -1,
      -1,    -1,    -1,    46,    47,    48,    -1,    -1,    -1,    -1,
     134,    -1,    -1,    -1,    -1,   151,   140,    -1,    61,    62,
      63,    64,    65,    -1,    67,    68,    69,    70,    -1,   153,
      -1,    -1,    -1,    -1,    -1,    -1,    79,    80,    81,    82,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    90,    91,    92,
      93,    94,    95,    96,    -1,    -1,    -1,    -1,   101,   102,
     103,    -1,    -1,    -1,    -1,   108,   109,   110,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   121,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      15,   134,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
     153,    15,    -1,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    15,    -1,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    15,    -1,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    15,    -1,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    15,    -1,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,   151,   152,    15,    -1,
      17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
      27,    28,    29,    30,    31,    32,    33,    34,   152,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    -1,    15,   152,    17,
      18,    19,    20,    21,    22,    23,    24,    25,    26,    27,
      28,    29,    30,    31,    32,    33,    34,    15,   152,    17,
      18,    19,    20,    21,    22,    23,    24,    25,    26,    27,
      28,    29,    30,    31,    32,    33,    34,    15,   152,    17,
      18,    19,    20,    21,    22,    23,    24,    25,    26,    27,
      28,    29,    30,    31,    32,    33,    34,    15,   152,    17,
      18,    19,    20,    21,    22,    23,    24,    25,    26,    27,
      28,    29,    30,    31,    32,    33,    34,    19,    20,    21,
      22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
      32,    33,    34,    -1,    15,   152,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    33,    34,    15,    -1,    17,    18,    19,    20,
      21,    22,    23,    24,    25,    26,    27,    28,    29,    30,
      31,    32,    33,    34,   152,    21,    22,    23,    24,    25,
      26,    27,    28,    29,    30,    31,    32,    33,    34,    -1,
      -1,    -1,    -1,    15,   152,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
      32,    33,    34,    15,   152,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
      32,    33,    34,    15,   152,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
      32,    33,    34,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    -1,    -1,    -1,    -1,
      15,   152,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      15,   152,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      15,    -1,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
     152,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    15,
     152,    17,    18,    19,    20,    21,    22,    23,    24,    25,
      26,    27,    28,    29,    30,    31,    32,    33,    34,    15,
     152,    17,    18,    19,    20,    21,    22,    23,    24,    25,
      26,    27,    28,    29,    30,    31,    32,    33,    34,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    15,   152,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    15,   152,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    15,   152,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    15,    -1,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,   152,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,     4,    -1,
      -1,    -1,    -1,    -1,    -1,    15,   152,    17,    18,    19,
      20,    21,    22,    23,    24,    25,    26,    27,    28,    29,
      30,    31,    32,    33,    34,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    38,    -1,     4,    -1,    -1,    -1,    -1,    -1,
      -1,    15,   151,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    67,   151,    -1,    -1,    -1,    36,    -1,    38,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,   151,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    67,    -1,   105,
      -1,    -1,   151,    -1,    -1,    -1,   112,   113,   114,   115,
     116,   117,   118,   119,   120,    -1,    -1,   123,   124,    -1,
     126,   127,   128,    -1,    -1,    -1,    -1,   133,   134,   135,
      -1,    -1,    -1,    -1,    -1,   105,   680,    -1,    -1,    -1,
      -1,   151,   112,   113,   114,   115,   116,    -1,   118,   119,
     120,   695,   696,   123,   124,    -1,   126,   127,   128,    -1,
      -1,    -1,    -1,   133,   134,   135,    -1,   711,    -1,    -1,
     714,    -1,    -1,    -1,    -1,    -1,    -1,   151,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   735,   736,   737,   738,    -1,   740,    -1,   742,    15,
     744,    17,    18,    19,    20,    21,    22,    23,    24,    25,
      26,    27,    28,    29,    30,    31,    32,    33,    34,    -1,
      15,    37,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      -1,   785,   786,    -1,   788,   789,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34,    15,    16,    17,    18,
      19,    20,    21,    22,    23,    24,    25,    26,    27,    28,
      29,    30,    31,    32,    33,    34
};

/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
   state STATE-NUM.  */
static const yytype_int16 yystos[] =
{
       0,   130,   131,   132,   141,   150,   159,   175,   176,   163,
     164,   161,   162,   284,   285,   279,   280,     0,   177,   165,
       4,   108,   109,   110,   215,    58,   136,   288,   289,    58,
     281,   282,    46,    47,    48,    61,    62,    63,    64,    65,
      67,    68,    69,    70,    79,    80,    81,    82,    90,    91,
      92,    93,    94,    95,    96,   101,   102,   103,   121,   134,
     153,   178,   190,   192,   215,   217,   228,   229,   231,   233,
     271,   286,   287,     4,    38,    67,   105,   112,   113,   114,
     115,   116,   118,   119,   120,   123,   124,   126,   127,   128,
     133,   134,   135,   166,     6,     7,     8,     9,    10,    11,
      12,    13,    14,   213,    37,    37,    37,     4,   134,   137,
     138,   139,   291,   292,    58,   289,   138,   139,   283,   292,
     282,    58,    58,    49,    50,    37,    37,     4,   160,    58,
      37,    37,    37,    37,    37,    37,    37,    37,    37,    37,
      37,    37,   179,    37,   193,    37,   151,   153,   214,   140,
       4,   160,     4,     3,     4,    30,    31,    37,    38,    39,
      51,    52,    53,    60,    66,    78,    83,    84,    85,    86,
      87,    88,    89,    97,    99,   115,   121,   122,   149,   156,
     157,   239,     4,     4,   170,     4,   169,   168,     4,     4,
       4,   239,     4,     3,     4,   171,     4,    37,   172,   173,
       4,   117,   237,   238,   237,     4,     4,     4,     4,    16,
      16,    59,   153,   291,    59,   153,   191,   272,     4,     4,
       4,     4,   180,     4,    67,   218,   219,   220,     4,     4,
       4,   160,   160,     4,   160,   152,   160,   230,   232,     4,
     234,   234,   182,   183,    37,   160,    37,   181,    58,    10,
     151,   167,    10,   151,   239,   239,   239,    37,    37,    37,
      37,    37,   240,    37,    37,   235,   236,   235,   235,   235,
      37,    37,   235,   235,    37,    37,    37,    37,   239,   239,
      15,    17,    18,    19,    20,    21,    22,    23,    24,    25,
      26,    27,    28,    29,    30,    31,    32,    33,    34,   151,
      10,   151,   239,   151,   151,     4,   151,    10,   151,   239,
     151,   151,   237,     4,   151,   173,   239,    10,    10,    10,
      58,   292,   292,   153,     4,   134,   137,   138,   139,    59,
     153,     4,    59,    67,    75,   102,   192,   248,     4,    59,
     273,   151,   152,   152,   177,   221,   160,    59,   151,   216,
     151,   152,   152,   152,   152,   152,   152,   152,   216,   152,
     216,   151,   234,   152,   152,   152,     4,     5,    37,   111,
     184,   188,   182,   152,   239,   172,   288,   239,   239,   165,
     239,   239,   152,   239,   239,   239,   239,   239,    37,     4,
     239,    37,   239,   239,   239,   239,   239,     4,   239,   239,
     239,   239,   239,   239,   239,   239,   239,   239,   239,   239,
     239,   239,   239,   239,   239,   239,   239,   239,   239,   239,
       4,     4,     4,   239,   239,     3,     4,     4,    16,     4,
     173,   237,   237,   237,   294,   153,   153,     4,   136,   153,
     290,   249,   160,   253,   257,   274,     4,    36,    37,   225,
     222,   220,     4,   160,   160,   234,   237,    37,     4,     5,
     111,   151,   188,   152,   151,   152,    59,    36,   151,   152,
     152,   151,   151,   152,     4,   152,   152,     4,   151,   151,
     152,   151,   152,   152,    16,   174,   152,   152,   152,   292,
     139,    58,   136,   153,    37,    40,   239,   261,   262,   259,
      16,   239,   263,   262,   239,   276,   151,     4,   156,   226,
     227,    16,   218,   152,    16,   185,    37,     4,     5,   111,
     188,     4,   239,   239,   239,   241,   152,   239,   239,     4,
     239,   172,   153,   295,    16,   293,    71,    72,    73,    74,
      75,    76,    77,   152,   260,    37,    37,   261,    16,   106,
     243,   191,    16,    95,   264,   258,     4,   106,   277,     4,
       4,   152,   227,    97,   223,    36,   189,   184,   187,    37,
     152,   152,   152,   152,   151,   152,   152,   152,   152,    59,
     292,   292,    37,    10,   152,   239,    16,    37,    38,   244,
      36,   243,    58,    37,   278,    37,   275,   152,    10,   216,
     184,   152,   184,   186,   239,   153,   295,    77,   239,   152,
     239,    37,   147,   245,   107,   246,   191,   239,   277,   239,
     153,   237,    99,   224,   152,   152,   184,   152,    59,    10,
      39,   261,   152,   239,   246,    37,   254,    59,   152,   152,
      10,   152,   239,    37,    16,   152,   143,   144,   145,   247,
     239,    58,   277,   237,   152,   239,   250,   152,   255,   152,
      58,   267,   261,     4,    41,    42,    43,    44,    45,    54,
      56,    67,    98,   100,   104,   121,   142,   146,   148,   153,
     154,   194,   195,   196,   199,   202,   203,   205,   208,   209,
     210,   215,     4,    59,    16,    37,    37,   160,    37,   206,
      37,    37,    37,     4,    54,    55,    56,    57,   195,   197,
     201,    37,     4,    54,   154,   196,   205,    59,    37,   214,
     268,    25,   265,   104,   195,   195,   207,   211,   237,    37,
     204,     4,   198,   194,   200,    37,    37,    37,    37,   155,
     216,   201,    37,   201,    37,   251,   237,    58,     4,   106,
     242,   152,   152,   152,   209,   152,   239,     4,   202,    21,
     152,   152,   194,    54,    55,   195,    54,    55,   195,   195,
     195,   197,   152,   155,   201,   265,   152,   209,    25,   266,
      36,   151,   152,     4,   194,    37,    37,   152,    37,    37,
     152,   152,   152,   152,   242,    59,     4,    10,    16,   212,
       4,   195,   195,   195,   195,   266,   269,   211,     4,   256,
     152,   152,   152,   152,   152,   212,   266,   216,   214,   152,
     152,   152,   152,   252,   212,   216,   270,   216
};

/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
static const yytype_int16 yyr1[] =
{
       0,   158,   159,   159,   159,   159,   159,   160,   162,   161,
     164,   163,   165,   165,   166,   166,   166,   166,   166,   166,
     166,   166,   166,   166,   166,   166,   166,   166,   166,   166,
     166,   166,   166,   166,   166,   166,   166,   166,   166,   166,
     167,   166,   166,   166,   168,   168,   168,   169,   169,   170,
     170,   171,   171,   171,   172,   172,   172,   172,   172,   172,
     174,   173,   176,   175,   177,   177,   178,   178,   178,   178,
     178,   178,   178,   178,   178,   178,   178,   178,   178,   178,
     178,   178,   178,   178,   178,   178,   179,   178,   178,   180,
     178,   178,   178,   181,   178,   178,   178,   178,   178,   183,
     182,   184,   184,   184,   184,   184,   184,   185,   184,   186,
     184,   187,   184,   184,   184,   184,   189,   188,   190,   191,
     191,   191,   192,   192,   193,   192,   194,   195,   195,   196,
     196,   196,   197,   197,   197,   197,   197,   197,   197,   197,
     197,   198,   198,   199,   200,   200,   201,   201,   202,   202,
     202,   202,   202,   202,   203,   204,   203,   205,   205,   205,
     205,   205,   205,   205,   205,   206,   205,   207,   205,   208,
     208,   209,   209,   210,   210,   210,   210,   210,   211,   212,
     212,   213,   213,   213,   213,   213,   213,   213,   213,   214,
     214,   215,   215,   215,   215,   215,   216,   216,   217,   218,
     218,   219,   219,   221,   220,   222,   220,   223,   224,   225,
     225,   226,   226,   227,   227,   228,   229,   229,   230,   230,
     231,   232,   232,   233,   233,   234,   234,   234,   236,   235,
     238,   237,   239,   239,   239,   239,   239,   239,   239,   239,
     239,   239,   239,   239,   239,   239,   239,   239,   239,   239,
     239,   239,   239,   239,   239,   239,   239,   239,   239,   239,
     239,   239,   239,   239,   239,   239,   239,   239,   239,   239,
     239,   240,   241,   239,   239,   239,   239,   239,   239,   239,
     239,   239,   242,   242,   243,   243,   244,   244,   245,   245,
     246,   246,   247,   247,   247,   247,   249,   250,   251,   252,
     248,   253,   254,   255,   256,   248,   257,   258,   248,   259,
     248,   260,   260,   260,   260,   260,   260,   260,   260,   261,
     261,   261,   262,   262,   262,   262,   263,   263,   264,   264,
     265,   265,   266,   266,   267,   268,   269,   270,   267,   271,
     272,   272,   274,   275,   273,   276,   277,   277,   277,   278,
     278,   280,   279,   281,   281,   282,   283,   285,   284,   287,
     286,   288,   288,   289,   289,   289,   290,   290,   291,   291,
     291,   291,   291,   292,   292,   292,   292,   293,   292,   294,
     292,   292,   292,   292,   292,   292,   292,   295,   295
};

/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr2[] =
{
       0,     2,     2,     2,     2,     2,     2,     1,     0,     2,
       0,     2,     3,     0,     2,     4,     1,     1,     2,     1,
       4,     4,     3,     2,     4,     3,     4,     4,     4,     4,
       4,     2,     2,     2,     4,     4,     2,     2,     2,     2,
       0,     5,     2,     0,     3,     2,     0,     1,     3,     1,
       3,     0,     1,     3,     1,     2,     3,     1,     2,     3,
       0,     6,     0,     2,     2,     0,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     4,     4,     4,     4,
       8,     4,     1,     1,     1,     4,     0,     5,     4,     0,
       5,     4,     4,     0,     5,     3,     3,     6,     4,     0,
       2,     1,     3,     2,     1,     3,     2,     0,     5,     0,
       7,     0,     6,     1,     3,     2,     0,     6,     4,     2,
       2,     0,     4,     2,     0,     7,     1,     1,     5,     1,
       4,     4,     1,     4,     4,     4,     7,     7,     7,     7,
       4,     1,     3,     4,     2,     1,     3,     1,     1,     2,
       3,     4,     4,     5,     1,     0,     5,     1,     2,     1,
       1,     4,     1,     4,     4,     0,     8,     0,     5,     2,
       1,     0,     1,     1,     1,     1,     1,     1,     1,     2,
       0,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     3,     3,     6,     6,     6,     1,     0,     4,     1,
       0,     3,     1,     0,     7,     0,     5,     3,     3,     0,
       3,     1,     2,     1,     2,     4,     4,     3,     3,     1,
       4,     3,     0,     1,     1,     0,     2,     3,     0,     4,
       0,     2,     2,     3,     4,     2,     2,     2,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     5,     3,     3,     4,     1,     1,
       2,     2,     2,     2,     4,     4,     4,     6,     6,     6,
       4,     0,     0,     8,     4,     1,     6,     6,     6,     2,
       2,     4,     3,     0,     4,     0,     4,     0,     1,     0,
       4,     0,     1,     1,     1,     0,     0,     0,     0,     0,
      19,     0,     0,     0,     0,    17,     0,     0,     7,     0,
       5,     1,     1,     1,     1,     1,     6,     1,     3,     3,
       0,     2,     3,     2,     6,    10,     2,     1,     0,     1,
       2,     0,     0,     3,     0,     0,     0,     0,    11,     4,
       0,     2,     0,     0,     6,     1,     0,     3,     5,     0,
       3,     0,     2,     1,     2,     4,     2,     0,     2,     0,
       5,     1,     2,     4,     5,     6,     1,     2,     0,     2,
       4,     4,     8,     1,     1,     3,     3,     0,     9,     0,
       7,     1,     3,     1,     3,     1,     3,     0,     1
};


enum { YYENOMEM = -2 };

#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYNOMEM         goto yyexhaustedlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                    \
  do                                                              \
    if (yychar == YYEMPTY)                                        \
      {                                                           \
        yychar = (Token);                                         \
        yylval = (Value);                                         \
        YYPOPSTACK (yylen);                                       \
        yystate = *yyssp;                                         \
        goto yybackup;                                            \
      }                                                           \
    else                                                          \
      {                                                           \
        yyerror (YY_("syntax error: cannot back up")); \
        YYERROR;                                                  \
      }                                                           \
  while (0)

/* Backward compatibility with an undocumented macro.
   Use YYerror or YYUNDEF. */
#define YYERRCODE YYUNDEF


/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)




# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Kind, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*-----------------------------------.
| Print this symbol's value on YYO.  |
`-----------------------------------*/

static void
yy_symbol_value_print (FILE *yyo,
                       yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  FILE *yyoutput = yyo;
  YY_USE (yyoutput);
  if (!yyvaluep)
    return;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/*---------------------------.
| Print this symbol on YYO.  |
`---------------------------*/

static void
yy_symbol_print (FILE *yyo,
                 yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyo, "%s %s (",
             yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));

  yy_symbol_value_print (yyo, yykind, yyvaluep);
  YYFPRINTF (yyo, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp,
                 int yyrule)
{
  int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       YY_ACCESSING_SYMBOL (+yyssp[yyi + 1 - yynrhs]),
                       &yyvsp[(yyi + 1) - (yynrhs)]);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args) ((void) 0)
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif






/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg,
            yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
{
  YY_USE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/* Lookahead token kind.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;




/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    yy_state_fast_t yystate = 0;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus = 0;

    /* Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* Their size.  */
    YYPTRDIFF_T yystacksize = YYINITDEPTH;

    /* The state stack: array, bottom, top.  */
    yy_state_t yyssa[YYINITDEPTH];
    yy_state_t *yyss = yyssa;
    yy_state_t *yyssp = yyss;

    /* The semantic value stack: array, bottom, top.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs = yyvsa;
    YYSTYPE *yyvsp = yyvs;

  int yyn;
  /* The return value of yyparse.  */
  int yyresult;
  /* Lookahead symbol kind.  */
  yysymbol_kind_t yytoken = YYSYMBOL_YYEMPTY;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;



#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yychar = YYEMPTY; /* Cause a token to be read.  */

  goto yysetstate;


/*------------------------------------------------------------.
| yynewstate -- push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;


/*--------------------------------------------------------------------.
| yysetstate -- set current state (the top of the stack) to yystate.  |
`--------------------------------------------------------------------*/
yysetstate:
  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
  YY_IGNORE_USELESS_CAST_BEGIN
  *yyssp = YY_CAST (yy_state_t, yystate);
  YY_IGNORE_USELESS_CAST_END
  YY_STACK_PRINT (yyss, yyssp);

  if (yyss + yystacksize - 1 <= yyssp)
#if !defined yyoverflow && !defined YYSTACK_RELOCATE
    YYNOMEM;
#else
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYPTRDIFF_T yysize = yyssp - yyss + 1;

# if defined yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        yy_state_t *yyss1 = yyss;
        YYSTYPE *yyvs1 = yyvs;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * YYSIZEOF (*yyssp),
                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                    &yystacksize);
        yyss = yyss1;
        yyvs = yyvs1;
      }
# else /* defined YYSTACK_RELOCATE */
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        YYNOMEM;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yy_state_t *yyss1 = yyss;
        union yyalloc *yyptr =
          YY_CAST (union yyalloc *,
                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
        if (! yyptr)
          YYNOMEM;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YY_IGNORE_USELESS_CAST_BEGIN
      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
                  YY_CAST (long, yystacksize)));
      YY_IGNORE_USELESS_CAST_END

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }
#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */


  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;


/*-----------.
| yybackup.  |
`-----------*/
yybackup:
  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token\n"));
      yychar = yylex ();
    }

  if (yychar <= YYEOF)
    {
      yychar = YYEOF;
      yytoken = YYSYMBOL_YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else if (yychar == YYerror)
    {
      /* The scanner already issued an error message, process directly
         to error recovery.  But do not keep the error token as
         lookahead, it is too special and may lead us to an endless
         loop in error recovery. */
      yychar = YYUNDEF;
      yytoken = YYSYMBOL_YYerror;
      goto yyerrlab1;
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  /* Discard the shifted token.  */
  yychar = YYEMPTY;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
  case 8: /* $@1: %empty  */
#line 181 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldlex_expression(); }
#line 2585 "ldgram.c"
    break;

  case 9: /* defsym_expr: $@1 assignment  */
#line 183 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldlex_popstate(); }
#line 2591 "ldgram.c"
    break;

  case 10: /* $@2: %empty  */
#line 188 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_mri_script ();
		  PUSH_ERROR (_("MRI style script"));
		}
#line 2600 "ldgram.c"
    break;

  case 11: /* mri_script_file: $@2 mri_script_lines  */
#line 193 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_popstate ();
		  mri_draw_tree ();
		  POP_ERROR ();
		}
#line 2610 "ldgram.c"
    break;

  case 16: /* mri_script_command: NAME  */
#line 208 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			einfo(_("%F%P: unrecognised keyword in MRI style script '%s'\n"),(yyvsp[0].name));
			}
#line 2618 "ldgram.c"
    break;

  case 17: /* mri_script_command: LIST  */
#line 211 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			config.map_filename = "-";
			}
#line 2626 "ldgram.c"
    break;

  case 20: /* mri_script_command: PUBLIC NAME '=' exp  */
#line 217 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_public((yyvsp[-2].name), (yyvsp[0].etree)); }
#line 2632 "ldgram.c"
    break;

  case 21: /* mri_script_command: PUBLIC NAME ',' exp  */
#line 219 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_public((yyvsp[-2].name), (yyvsp[0].etree)); }
#line 2638 "ldgram.c"
    break;

  case 22: /* mri_script_command: PUBLIC NAME exp  */
#line 221 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_public((yyvsp[-1].name), (yyvsp[0].etree)); }
#line 2644 "ldgram.c"
    break;

  case 23: /* mri_script_command: FORMAT NAME  */
#line 223 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_format((yyvsp[0].name)); }
#line 2650 "ldgram.c"
    break;

  case 24: /* mri_script_command: SECT NAME ',' exp  */
#line 225 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_output_section((yyvsp[-2].name), (yyvsp[0].etree));}
#line 2656 "ldgram.c"
    break;

  case 25: /* mri_script_command: SECT NAME exp  */
#line 227 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_output_section((yyvsp[-1].name), (yyvsp[0].etree));}
#line 2662 "ldgram.c"
    break;

  case 26: /* mri_script_command: SECT NAME '=' exp  */
#line 229 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_output_section((yyvsp[-2].name), (yyvsp[0].etree));}
#line 2668 "ldgram.c"
    break;

  case 27: /* mri_script_command: ALIGN_K NAME '=' exp  */
#line 231 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_align((yyvsp[-2].name),(yyvsp[0].etree)); }
#line 2674 "ldgram.c"
    break;

  case 28: /* mri_script_command: ALIGN_K NAME ',' exp  */
#line 233 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_align((yyvsp[-2].name),(yyvsp[0].etree)); }
#line 2680 "ldgram.c"
    break;

  case 29: /* mri_script_command: ALIGNMOD NAME '=' exp  */
#line 235 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_alignmod((yyvsp[-2].name),(yyvsp[0].etree)); }
#line 2686 "ldgram.c"
    break;

  case 30: /* mri_script_command: ALIGNMOD NAME ',' exp  */
#line 237 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_alignmod((yyvsp[-2].name),(yyvsp[0].etree)); }
#line 2692 "ldgram.c"
    break;

  case 33: /* mri_script_command: NAMEWORD NAME  */
#line 241 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_name((yyvsp[0].name)); }
#line 2698 "ldgram.c"
    break;

  case 34: /* mri_script_command: ALIAS NAME ',' NAME  */
#line 243 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_alias((yyvsp[-2].name),(yyvsp[0].name),0);}
#line 2704 "ldgram.c"
    break;

  case 35: /* mri_script_command: ALIAS NAME ',' INT  */
#line 245 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_alias ((yyvsp[-2].name), 0, (int) (yyvsp[0].bigint).integer); }
#line 2710 "ldgram.c"
    break;

  case 36: /* mri_script_command: BASE exp  */
#line 247 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_base((yyvsp[0].etree)); }
#line 2716 "ldgram.c"
    break;

  case 37: /* mri_script_command: TRUNCATE INT  */
#line 249 "../../binutils-ia16-20230531/ld/ldgram.y"
                { mri_truncate ((unsigned int) (yyvsp[0].bigint).integer); }
#line 2722 "ldgram.c"
    break;

  case 40: /* $@3: %empty  */
#line 253 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldfile_open_command_file ((yyvsp[0].name)); }
#line 2728 "ldgram.c"
    break;

  case 42: /* mri_script_command: START NAME  */
#line 256 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_add_entry ((yyvsp[0].name), false); }
#line 2734 "ldgram.c"
    break;

  case 44: /* ordernamelist: ordernamelist ',' NAME  */
#line 261 "../../binutils-ia16-20230531/ld/ldgram.y"
                                             { mri_order((yyvsp[0].name)); }
#line 2740 "ldgram.c"
    break;

  case 45: /* ordernamelist: ordernamelist NAME  */
#line 262 "../../binutils-ia16-20230531/ld/ldgram.y"
                                          { mri_order((yyvsp[0].name)); }
#line 2746 "ldgram.c"
    break;

  case 47: /* mri_load_name_list: NAME  */
#line 268 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_load((yyvsp[0].name)); }
#line 2752 "ldgram.c"
    break;

  case 48: /* mri_load_name_list: mri_load_name_list ',' NAME  */
#line 269 "../../binutils-ia16-20230531/ld/ldgram.y"
                                            { mri_load((yyvsp[0].name)); }
#line 2758 "ldgram.c"
    break;

  case 49: /* mri_abs_name_list: NAME  */
#line 274 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_only_load((yyvsp[0].name)); }
#line 2764 "ldgram.c"
    break;

  case 50: /* mri_abs_name_list: mri_abs_name_list ',' NAME  */
#line 276 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { mri_only_load((yyvsp[0].name)); }
#line 2770 "ldgram.c"
    break;

  case 51: /* casesymlist: %empty  */
#line 280 "../../binutils-ia16-20230531/ld/ldgram.y"
                      { (yyval.name) = NULL; }
#line 2776 "ldgram.c"
    break;

  case 54: /* extern_name_list: NAME  */
#line 287 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { if (ldgram_cond)
			    ldlang_add_undef ((yyvsp[0].name), false); }
#line 2783 "ldgram.c"
    break;

  case 55: /* extern_name_list: extern_name_list NAME  */
#line 290 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { if (ldgram_cond)
			    ldlang_add_undef ((yyvsp[0].name), false); }
#line 2790 "ldgram.c"
    break;

  case 56: /* extern_name_list: extern_name_list ',' NAME  */
#line 293 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { if (ldgram_cond)
			    ldlang_add_undef ((yyvsp[0].name), false); }
#line 2797 "ldgram.c"
    break;

  case 60: /* @4: %empty  */
#line 304 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.integer) = ldgram_cond;
		  if (ldgram_cond)
		    {
		      exp_fold_tree_no_dot ((yyvsp[-1].etree));
		      if (! expld.result.valid_p)
			einfo (_("\
%X%P:%pS: cannot evaluate condition for EXTERN\n"), NULL);
		      else
			ldgram_cond = !! expld.result.value;
		    }
		}
#line 2813 "ldgram.c"
    break;

  case 61: /* cond_extern_name_list: '(' mustbe_exp ':' @4 extern_name_list ')'  */
#line 316 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldgram_cond = (yyvsp[-2].integer); }
#line 2819 "ldgram.c"
    break;

  case 62: /* $@5: %empty  */
#line 320 "../../binutils-ia16-20230531/ld/ldgram.y"
        { ldlex_script (); }
#line 2825 "ldgram.c"
    break;

  case 63: /* script_file: $@5 ifile_list  */
#line 322 "../../binutils-ia16-20230531/ld/ldgram.y"
        { ldlex_popstate (); }
#line 2831 "ldgram.c"
    break;

  case 76: /* ifile_p1: TARGET_K '(' NAME ')'  */
#line 343 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_add_target((yyvsp[-1].name)); }
#line 2837 "ldgram.c"
    break;

  case 77: /* ifile_p1: SEARCH_DIR '(' filename ')'  */
#line 345 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldfile_add_library_path ((yyvsp[-1].name), false); }
#line 2843 "ldgram.c"
    break;

  case 78: /* ifile_p1: OUTPUT '(' filename ')'  */
#line 347 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_add_output((yyvsp[-1].name), 1); }
#line 2849 "ldgram.c"
    break;

  case 79: /* ifile_p1: OUTPUT_FORMAT '(' NAME ')'  */
#line 349 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { lang_add_output_format ((yyvsp[-1].name), (char *) NULL,
					    (char *) NULL, 1); }
#line 2856 "ldgram.c"
    break;

  case 80: /* ifile_p1: OUTPUT_FORMAT '(' NAME ',' NAME ',' NAME ')'  */
#line 352 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { lang_add_output_format ((yyvsp[-5].name), (yyvsp[-3].name), (yyvsp[-1].name), 1); }
#line 2862 "ldgram.c"
    break;

  case 81: /* ifile_p1: OUTPUT_ARCH '(' NAME ')'  */
#line 354 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { ldfile_set_output_arch ((yyvsp[-1].name), bfd_arch_unknown); }
#line 2868 "ldgram.c"
    break;

  case 82: /* ifile_p1: FORCE_COMMON_ALLOCATION  */
#line 356 "../../binutils-ia16-20230531/ld/ldgram.y"
                { command_line.force_common_definition = true ; }
#line 2874 "ldgram.c"
    break;

  case 83: /* ifile_p1: FORCE_GROUP_ALLOCATION  */
#line 358 "../../binutils-ia16-20230531/ld/ldgram.y"
                { command_line.force_group_allocation = true ; }
#line 2880 "ldgram.c"
    break;

  case 84: /* ifile_p1: INHIBIT_COMMON_ALLOCATION  */
#line 360 "../../binutils-ia16-20230531/ld/ldgram.y"
                { link_info.inhibit_common_definition = true ; }
#line 2886 "ldgram.c"
    break;

  case 86: /* $@6: %empty  */
#line 363 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { lang_enter_group (); }
#line 2892 "ldgram.c"
    break;

  case 87: /* ifile_p1: GROUP $@6 '(' input_list ')'  */
#line 365 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { lang_leave_group (); }
#line 2898 "ldgram.c"
    break;

  case 88: /* ifile_p1: MAP '(' filename ')'  */
#line 367 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_add_map((yyvsp[-1].name)); }
#line 2904 "ldgram.c"
    break;

  case 89: /* $@7: %empty  */
#line 369 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldfile_open_command_file ((yyvsp[0].name)); }
#line 2910 "ldgram.c"
    break;

  case 91: /* ifile_p1: NOCROSSREFS '(' nocrossref_list ')'  */
#line 372 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_nocrossref ((yyvsp[-1].nocrossref));
		}
#line 2918 "ldgram.c"
    break;

  case 92: /* ifile_p1: NOCROSSREFS_TO '(' nocrossref_list ')'  */
#line 376 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_nocrossref_to ((yyvsp[-1].nocrossref));
		}
#line 2926 "ldgram.c"
    break;

  case 93: /* $@8: %empty  */
#line 379 "../../binutils-ia16-20230531/ld/ldgram.y"
                           { ldlex_expression (); }
#line 2932 "ldgram.c"
    break;

  case 94: /* ifile_p1: EXTERN '(' $@8 extern_name_list ')'  */
#line 380 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_popstate (); }
#line 2938 "ldgram.c"
    break;

  case 95: /* ifile_p1: INSERT_K AFTER NAME  */
#line 382 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_add_insert ((yyvsp[0].name), 0); }
#line 2944 "ldgram.c"
    break;

  case 96: /* ifile_p1: INSERT_K BEFORE NAME  */
#line 384 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_add_insert ((yyvsp[0].name), 1); }
#line 2950 "ldgram.c"
    break;

  case 97: /* ifile_p1: REGION_ALIAS '(' NAME ',' NAME ')'  */
#line 386 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_memory_region_alias ((yyvsp[-3].name), (yyvsp[-1].name)); }
#line 2956 "ldgram.c"
    break;

  case 98: /* ifile_p1: LD_FEATURE '(' NAME ')'  */
#line 388 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_ld_feature ((yyvsp[-1].name)); }
#line 2962 "ldgram.c"
    break;

  case 99: /* $@9: %empty  */
#line 392 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldlex_inputlist(); }
#line 2968 "ldgram.c"
    break;

  case 100: /* input_list: $@9 input_list1  */
#line 394 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldlex_popstate(); }
#line 2974 "ldgram.c"
    break;

  case 101: /* input_list1: NAME  */
#line 398 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_cond_add_input_file((yyvsp[0].name),
					   lang_input_file_is_search_file_enum,
					   (char *)NULL, ldgram_cond); }
#line 2982 "ldgram.c"
    break;

  case 102: /* input_list1: input_list1 ',' NAME  */
#line 402 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_cond_add_input_file((yyvsp[0].name),
					   lang_input_file_is_search_file_enum,
					   (char *)NULL, ldgram_cond); }
#line 2990 "ldgram.c"
    break;

  case 103: /* input_list1: input_list1 NAME  */
#line 406 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_cond_add_input_file((yyvsp[0].name),
					   lang_input_file_is_search_file_enum,
					   (char *)NULL, ldgram_cond); }
#line 2998 "ldgram.c"
    break;

  case 104: /* input_list1: LNAME  */
#line 410 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_cond_add_input_file((yyvsp[0].name),lang_input_file_is_l_enum,
					   (char *)NULL, ldgram_cond); }
#line 3005 "ldgram.c"
    break;

  case 105: /* input_list1: input_list1 ',' LNAME  */
#line 413 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_cond_add_input_file((yyvsp[0].name),lang_input_file_is_l_enum,
					   (char *)NULL, ldgram_cond); }
#line 3012 "ldgram.c"
    break;

  case 106: /* input_list1: input_list1 LNAME  */
#line 416 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_cond_add_input_file((yyvsp[0].name),lang_input_file_is_l_enum,
					   (char *)NULL, ldgram_cond); }
#line 3019 "ldgram.c"
    break;

  case 107: /* @10: %empty  */
#line 419 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { (yyval.integer) = input_flags.add_DT_NEEDED_for_regular;
		    input_flags.add_DT_NEEDED_for_regular = true; }
#line 3026 "ldgram.c"
    break;

  case 108: /* input_list1: AS_NEEDED '(' @10 input_list1 ')'  */
#line 422 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { input_flags.add_DT_NEEDED_for_regular = (yyvsp[-2].integer); }
#line 3032 "ldgram.c"
    break;

  case 109: /* @11: %empty  */
#line 424 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { (yyval.integer) = input_flags.add_DT_NEEDED_for_regular;
		    input_flags.add_DT_NEEDED_for_regular = true; }
#line 3039 "ldgram.c"
    break;

  case 110: /* input_list1: input_list1 ',' AS_NEEDED '(' @11 input_list1 ')'  */
#line 427 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { input_flags.add_DT_NEEDED_for_regular = (yyvsp[-2].integer); }
#line 3045 "ldgram.c"
    break;

  case 111: /* @12: %empty  */
#line 429 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { (yyval.integer) = input_flags.add_DT_NEEDED_for_regular;
		    input_flags.add_DT_NEEDED_for_regular = true; }
#line 3052 "ldgram.c"
    break;

  case 112: /* input_list1: input_list1 AS_NEEDED '(' @12 input_list1 ')'  */
#line 432 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { input_flags.add_DT_NEEDED_for_regular = (yyvsp[-2].integer); }
#line 3058 "ldgram.c"
    break;

  case 116: /* @13: %empty  */
#line 442 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { (yyval.integer) = ldgram_cond;
		    if (ldgram_cond)
		      {
			exp_fold_tree_no_dot ((yyvsp[-1].etree));
			if (! expld.result.valid_p)
			  einfo (_("\
%X%P:%pS: cannot evaluate condition for INPUT\n"), NULL);
			else
			  ldgram_cond = !! expld.result.value;
		      }
		  }
#line 3074 "ldgram.c"
    break;

  case 117: /* cond_input_list: '(' mustbe_exp ':' @13 input_list1 ')'  */
#line 454 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { ldgram_cond = (yyvsp[-2].integer); }
#line 3080 "ldgram.c"
    break;

  case 122: /* statement_anywhere: ENTRY '(' NAME ')'  */
#line 469 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_add_entry ((yyvsp[-1].name), false); }
#line 3086 "ldgram.c"
    break;

  case 124: /* $@14: %empty  */
#line 471 "../../binutils-ia16-20230531/ld/ldgram.y"
                          {ldlex_expression ();}
#line 3092 "ldgram.c"
    break;

  case 125: /* statement_anywhere: ASSERT_K $@14 '(' exp ',' NAME ')'  */
#line 472 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldlex_popstate ();
		  lang_add_assignment (exp_assert ((yyvsp[-3].etree), (yyvsp[-1].name))); }
#line 3099 "ldgram.c"
    break;

  case 126: /* wildcard_name: NAME  */
#line 478 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.cname) = (yyvsp[0].name);
			}
#line 3107 "ldgram.c"
    break;

  case 127: /* wildcard_maybe_exclude: wildcard_name  */
#line 485 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard).name = (yyvsp[0].cname);
			  (yyval.wildcard).sorted = none;
			  (yyval.wildcard).exclude_name_list = NULL;
			  (yyval.wildcard).section_flag_list = NULL;
			}
#line 3118 "ldgram.c"
    break;

  case 128: /* wildcard_maybe_exclude: EXCLUDE_FILE '(' exclude_name_list ')' wildcard_name  */
#line 492 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard).name = (yyvsp[0].cname);
			  (yyval.wildcard).sorted = none;
			  (yyval.wildcard).exclude_name_list = (yyvsp[-2].name_list);
			  (yyval.wildcard).section_flag_list = NULL;
			}
#line 3129 "ldgram.c"
    break;

  case 130: /* filename_spec: SORT_BY_NAME '(' wildcard_maybe_exclude ')'  */
#line 503 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-1].wildcard);
			  (yyval.wildcard).sorted = by_name;
			}
#line 3138 "ldgram.c"
    break;

  case 131: /* filename_spec: SORT_NONE '(' wildcard_maybe_exclude ')'  */
#line 508 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-1].wildcard);
			  (yyval.wildcard).sorted = by_none;
			}
#line 3147 "ldgram.c"
    break;

  case 133: /* section_name_spec: SORT_BY_NAME '(' wildcard_maybe_exclude ')'  */
#line 517 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-1].wildcard);
			  (yyval.wildcard).sorted = by_name;
			}
#line 3156 "ldgram.c"
    break;

  case 134: /* section_name_spec: SORT_BY_ALIGNMENT '(' wildcard_maybe_exclude ')'  */
#line 522 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-1].wildcard);
			  (yyval.wildcard).sorted = by_alignment;
			}
#line 3165 "ldgram.c"
    break;

  case 135: /* section_name_spec: SORT_NONE '(' wildcard_maybe_exclude ')'  */
#line 527 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-1].wildcard);
			  (yyval.wildcard).sorted = by_none;
			}
#line 3174 "ldgram.c"
    break;

  case 136: /* section_name_spec: SORT_BY_NAME '(' SORT_BY_ALIGNMENT '(' wildcard_maybe_exclude ')' ')'  */
#line 532 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-2].wildcard);
			  (yyval.wildcard).sorted = by_name_alignment;
			}
#line 3183 "ldgram.c"
    break;

  case 137: /* section_name_spec: SORT_BY_NAME '(' SORT_BY_NAME '(' wildcard_maybe_exclude ')' ')'  */
#line 537 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-2].wildcard);
			  (yyval.wildcard).sorted = by_name;
			}
#line 3192 "ldgram.c"
    break;

  case 138: /* section_name_spec: SORT_BY_ALIGNMENT '(' SORT_BY_NAME '(' wildcard_maybe_exclude ')' ')'  */
#line 542 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-2].wildcard);
			  (yyval.wildcard).sorted = by_alignment_name;
			}
#line 3201 "ldgram.c"
    break;

  case 139: /* section_name_spec: SORT_BY_ALIGNMENT '(' SORT_BY_ALIGNMENT '(' wildcard_maybe_exclude ')' ')'  */
#line 547 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-2].wildcard);
			  (yyval.wildcard).sorted = by_alignment;
			}
#line 3210 "ldgram.c"
    break;

  case 140: /* section_name_spec: SORT_BY_INIT_PRIORITY '(' wildcard_maybe_exclude ')'  */
#line 552 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.wildcard) = (yyvsp[-1].wildcard);
			  (yyval.wildcard).sorted = by_init_priority;
			}
#line 3219 "ldgram.c"
    break;

  case 141: /* sect_flag_list: NAME  */
#line 559 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct flag_info_list *n;
			  n = ((struct flag_info_list *) xmalloc (sizeof *n));
			  if ((yyvsp[0].name)[0] == '!')
			    {
			      n->with = without_flags;
			      n->name = &(yyvsp[0].name)[1];
			    }
			  else
			    {
			      n->with = with_flags;
			      n->name = (yyvsp[0].name);
			    }
			  n->valid = false;
			  n->next = NULL;
			  (yyval.flag_info_list) = n;
			}
#line 3241 "ldgram.c"
    break;

  case 142: /* sect_flag_list: sect_flag_list '&' NAME  */
#line 577 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct flag_info_list *n;
			  n = ((struct flag_info_list *) xmalloc (sizeof *n));
			  if ((yyvsp[0].name)[0] == '!')
			    {
			      n->with = without_flags;
			      n->name = &(yyvsp[0].name)[1];
			    }
			  else
			    {
			      n->with = with_flags;
			      n->name = (yyvsp[0].name);
			    }
			  n->valid = false;
			  n->next = (yyvsp[-2].flag_info_list);
			  (yyval.flag_info_list) = n;
			}
#line 3263 "ldgram.c"
    break;

  case 143: /* sect_flags: INPUT_SECTION_FLAGS '(' sect_flag_list ')'  */
#line 598 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct flag_info *n;
			  n = ((struct flag_info *) xmalloc (sizeof *n));
			  n->flag_list = (yyvsp[-1].flag_info_list);
			  n->flags_initialized = false;
			  n->not_with_flags = 0;
			  n->only_with_flags = 0;
			  (yyval.flag_info) = n;
			}
#line 3277 "ldgram.c"
    break;

  case 144: /* exclude_name_list: exclude_name_list wildcard_name  */
#line 611 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct name_list *tmp;
			  tmp = (struct name_list *) xmalloc (sizeof *tmp);
			  tmp->name = (yyvsp[0].cname);
			  tmp->next = (yyvsp[-1].name_list);
			  (yyval.name_list) = tmp;
			}
#line 3289 "ldgram.c"
    break;

  case 145: /* exclude_name_list: wildcard_name  */
#line 620 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct name_list *tmp;
			  tmp = (struct name_list *) xmalloc (sizeof *tmp);
			  tmp->name = (yyvsp[0].cname);
			  tmp->next = NULL;
			  (yyval.name_list) = tmp;
			}
#line 3301 "ldgram.c"
    break;

  case 146: /* section_name_list: section_name_list opt_comma section_name_spec  */
#line 631 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct wildcard_list *tmp;
			  tmp = (struct wildcard_list *) xmalloc (sizeof *tmp);
			  tmp->next = (yyvsp[-2].wildcard_list);
			  tmp->spec = (yyvsp[0].wildcard);
			  (yyval.wildcard_list) = tmp;
			}
#line 3313 "ldgram.c"
    break;

  case 147: /* section_name_list: section_name_spec  */
#line 640 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct wildcard_list *tmp;
			  tmp = (struct wildcard_list *) xmalloc (sizeof *tmp);
			  tmp->next = NULL;
			  tmp->spec = (yyvsp[0].wildcard);
			  (yyval.wildcard_list) = tmp;
			}
#line 3325 "ldgram.c"
    break;

  case 148: /* input_section_spec_no_keep: NAME  */
#line 651 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct wildcard_spec tmp;
			  tmp.name = (yyvsp[0].name);
			  tmp.exclude_name_list = NULL;
			  tmp.sorted = none;
			  tmp.section_flag_list = NULL;
			  lang_add_wild (&tmp, NULL, ldgram_had_keep);
			}
#line 3338 "ldgram.c"
    break;

  case 149: /* input_section_spec_no_keep: sect_flags NAME  */
#line 660 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct wildcard_spec tmp;
			  tmp.name = (yyvsp[0].name);
			  tmp.exclude_name_list = NULL;
			  tmp.sorted = none;
			  tmp.section_flag_list = (yyvsp[-1].flag_info);
			  lang_add_wild (&tmp, NULL, ldgram_had_keep);
			}
#line 3351 "ldgram.c"
    break;

  case 150: /* input_section_spec_no_keep: '[' section_name_list ']'  */
#line 669 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  lang_add_wild (NULL, (yyvsp[-1].wildcard_list), ldgram_had_keep);
			}
#line 3359 "ldgram.c"
    break;

  case 151: /* input_section_spec_no_keep: sect_flags '[' section_name_list ']'  */
#line 673 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct wildcard_spec tmp;
			  tmp.name = NULL;
			  tmp.exclude_name_list = NULL;
			  tmp.sorted = none;
			  tmp.section_flag_list = (yyvsp[-3].flag_info);
			  lang_add_wild (&tmp, (yyvsp[-1].wildcard_list), ldgram_had_keep);
			}
#line 3372 "ldgram.c"
    break;

  case 152: /* input_section_spec_no_keep: filename_spec '(' section_name_list ')'  */
#line 682 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  lang_add_wild (&(yyvsp[-3].wildcard), (yyvsp[-1].wildcard_list), ldgram_had_keep);
			}
#line 3380 "ldgram.c"
    break;

  case 153: /* input_section_spec_no_keep: sect_flags filename_spec '(' section_name_list ')'  */
#line 686 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyvsp[-3].wildcard).section_flag_list = (yyvsp[-4].flag_info);
			  lang_add_wild (&(yyvsp[-3].wildcard), (yyvsp[-1].wildcard_list), ldgram_had_keep);
			}
#line 3389 "ldgram.c"
    break;

  case 155: /* $@15: %empty  */
#line 695 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldgram_had_keep = true; }
#line 3395 "ldgram.c"
    break;

  case 156: /* input_section_spec: KEEP '(' $@15 input_section_spec_no_keep ')'  */
#line 697 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldgram_had_keep = false; }
#line 3401 "ldgram.c"
    break;

  case 159: /* statement: CREATE_OBJECT_SYMBOLS  */
#line 704 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_attribute (lang_object_symbols_statement_enum);
		}
#line 3409 "ldgram.c"
    break;

  case 160: /* statement: CONSTRUCTORS  */
#line 708 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_attribute (lang_constructors_statement_enum);
		}
#line 3417 "ldgram.c"
    break;

  case 161: /* statement: SORT_BY_NAME '(' CONSTRUCTORS ')'  */
#line 712 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  constructors_sorted = true;
		  lang_add_attribute (lang_constructors_statement_enum);
		}
#line 3426 "ldgram.c"
    break;

  case 163: /* statement: length '(' mustbe_exp ')'  */
#line 718 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_data ((int) (yyvsp[-3].integer), (yyvsp[-1].etree));
		}
#line 3434 "ldgram.c"
    break;

  case 164: /* statement: FILL '(' fill_exp ')'  */
#line 723 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_fill ((yyvsp[-1].fill));
		}
#line 3442 "ldgram.c"
    break;

  case 165: /* $@16: %empty  */
#line 727 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldlex_expression (); }
#line 3448 "ldgram.c"
    break;

  case 166: /* statement: ASSERT_K $@16 '(' exp ',' NAME ')' separator  */
#line 729 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_popstate ();
		  lang_add_assignment (exp_assert ((yyvsp[-4].etree), (yyvsp[-2].name)));
		}
#line 3457 "ldgram.c"
    break;

  case 167: /* $@17: %empty  */
#line 734 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldfile_open_command_file ((yyvsp[0].name));
		}
#line 3465 "ldgram.c"
    break;

  case 173: /* length: QUAD  */
#line 752 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.integer) = (yyvsp[0].token); }
#line 3471 "ldgram.c"
    break;

  case 174: /* length: SQUAD  */
#line 754 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.integer) = (yyvsp[0].token); }
#line 3477 "ldgram.c"
    break;

  case 175: /* length: LONG  */
#line 756 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.integer) = (yyvsp[0].token); }
#line 3483 "ldgram.c"
    break;

  case 176: /* length: SHORT  */
#line 758 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.integer) = (yyvsp[0].token); }
#line 3489 "ldgram.c"
    break;

  case 177: /* length: BYTE  */
#line 760 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.integer) = (yyvsp[0].token); }
#line 3495 "ldgram.c"
    break;

  case 178: /* fill_exp: mustbe_exp  */
#line 765 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.fill) = exp_get_fill ((yyvsp[0].etree), 0, "fill value");
		}
#line 3503 "ldgram.c"
    break;

  case 179: /* fill_opt: '=' fill_exp  */
#line 772 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.fill) = (yyvsp[0].fill); }
#line 3509 "ldgram.c"
    break;

  case 180: /* fill_opt: %empty  */
#line 773 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.fill) = (fill_type *) 0; }
#line 3515 "ldgram.c"
    break;

  case 181: /* assign_op: PLUSEQ  */
#line 778 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = '+'; }
#line 3521 "ldgram.c"
    break;

  case 182: /* assign_op: MINUSEQ  */
#line 780 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = '-'; }
#line 3527 "ldgram.c"
    break;

  case 183: /* assign_op: MULTEQ  */
#line 782 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = '*'; }
#line 3533 "ldgram.c"
    break;

  case 184: /* assign_op: DIVEQ  */
#line 784 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = '/'; }
#line 3539 "ldgram.c"
    break;

  case 185: /* assign_op: LSHIFTEQ  */
#line 786 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = LSHIFT; }
#line 3545 "ldgram.c"
    break;

  case 186: /* assign_op: RSHIFTEQ  */
#line 788 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = RSHIFT; }
#line 3551 "ldgram.c"
    break;

  case 187: /* assign_op: ANDEQ  */
#line 790 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = '&'; }
#line 3557 "ldgram.c"
    break;

  case 188: /* assign_op: OREQ  */
#line 792 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = '|'; }
#line 3563 "ldgram.c"
    break;

  case 191: /* assignment: NAME '=' mustbe_exp  */
#line 802 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_assignment (exp_assign ((yyvsp[-2].name), (yyvsp[0].etree), false));
		}
#line 3571 "ldgram.c"
    break;

  case 192: /* assignment: NAME assign_op mustbe_exp  */
#line 806 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_assignment (exp_assign ((yyvsp[-2].name),
						   exp_binop ((yyvsp[-1].token),
							      exp_nameop (NAME,
									  (yyvsp[-2].name)),
							      (yyvsp[0].etree)), false));
		}
#line 3583 "ldgram.c"
    break;

  case 193: /* assignment: HIDDEN '(' NAME '=' mustbe_exp ')'  */
#line 814 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_assignment (exp_assign ((yyvsp[-3].name), (yyvsp[-1].etree), true));
		}
#line 3591 "ldgram.c"
    break;

  case 194: /* assignment: PROVIDE '(' NAME '=' mustbe_exp ')'  */
#line 818 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_assignment (exp_provide ((yyvsp[-3].name), (yyvsp[-1].etree), false));
		}
#line 3599 "ldgram.c"
    break;

  case 195: /* assignment: PROVIDE_HIDDEN '(' NAME '=' mustbe_exp ')'  */
#line 822 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_add_assignment (exp_provide ((yyvsp[-3].name), (yyvsp[-1].etree), true));
		}
#line 3607 "ldgram.c"
    break;

  case 203: /* $@18: %empty  */
#line 845 "../../binutils-ia16-20230531/ld/ldgram.y"
                { region = lang_memory_region_lookup ((yyvsp[0].name), true); }
#line 3613 "ldgram.c"
    break;

  case 204: /* memory_spec: NAME $@18 attributes_opt ':' origin_spec opt_comma length_spec  */
#line 848 "../../binutils-ia16-20230531/ld/ldgram.y"
                {}
#line 3619 "ldgram.c"
    break;

  case 205: /* $@19: %empty  */
#line 850 "../../binutils-ia16-20230531/ld/ldgram.y"
                { ldfile_open_command_file ((yyvsp[0].name)); }
#line 3625 "ldgram.c"
    break;

  case 207: /* origin_spec: ORIGIN '=' mustbe_exp  */
#line 856 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  region->origin_exp = (yyvsp[0].etree);
		}
#line 3633 "ldgram.c"
    break;

  case 208: /* length_spec: LENGTH '=' mustbe_exp  */
#line 863 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  if (yychar == NAME)
		    {
		      yyclearin;
		      ldlex_backup ();
		    }
		  region->length_exp = (yyvsp[0].etree);
		}
#line 3646 "ldgram.c"
    break;

  case 209: /* attributes_opt: %empty  */
#line 875 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { /* dummy action to avoid bison 1.25 error message */ }
#line 3652 "ldgram.c"
    break;

  case 213: /* attributes_string: NAME  */
#line 886 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { lang_set_flags (region, (yyvsp[0].name), 0); }
#line 3658 "ldgram.c"
    break;

  case 214: /* attributes_string: '!' NAME  */
#line 888 "../../binutils-ia16-20230531/ld/ldgram.y"
                  { lang_set_flags (region, (yyvsp[0].name), 1); }
#line 3664 "ldgram.c"
    break;

  case 215: /* startup: STARTUP '(' filename ')'  */
#line 893 "../../binutils-ia16-20230531/ld/ldgram.y"
                { lang_startup((yyvsp[-1].name)); }
#line 3670 "ldgram.c"
    break;

  case 217: /* high_level_library: HLL '(' ')'  */
#line 899 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldemul_hll((char *)NULL); }
#line 3676 "ldgram.c"
    break;

  case 218: /* high_level_library_NAME_list: high_level_library_NAME_list opt_comma filename  */
#line 904 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldemul_hll((yyvsp[0].name)); }
#line 3682 "ldgram.c"
    break;

  case 219: /* high_level_library_NAME_list: filename  */
#line 906 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldemul_hll((yyvsp[0].name)); }
#line 3688 "ldgram.c"
    break;

  case 221: /* low_level_library_NAME_list: low_level_library_NAME_list opt_comma filename  */
#line 915 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldemul_syslib((yyvsp[0].name)); }
#line 3694 "ldgram.c"
    break;

  case 223: /* floating_point_support: FLOAT  */
#line 921 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { lang_float(true); }
#line 3700 "ldgram.c"
    break;

  case 224: /* floating_point_support: NOFLOAT  */
#line 923 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { lang_float(false); }
#line 3706 "ldgram.c"
    break;

  case 225: /* nocrossref_list: %empty  */
#line 928 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.nocrossref) = NULL;
		}
#line 3714 "ldgram.c"
    break;

  case 226: /* nocrossref_list: NAME nocrossref_list  */
#line 932 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  struct lang_nocrossref *n;

		  n = (struct lang_nocrossref *) xmalloc (sizeof *n);
		  n->name = (yyvsp[-1].name);
		  n->next = (yyvsp[0].nocrossref);
		  (yyval.nocrossref) = n;
		}
#line 3727 "ldgram.c"
    break;

  case 227: /* nocrossref_list: NAME ',' nocrossref_list  */
#line 941 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  struct lang_nocrossref *n;

		  n = (struct lang_nocrossref *) xmalloc (sizeof *n);
		  n->name = (yyvsp[-2].name);
		  n->next = (yyvsp[0].nocrossref);
		  (yyval.nocrossref) = n;
		}
#line 3740 "ldgram.c"
    break;

  case 228: /* $@20: %empty  */
#line 951 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_script (); }
#line 3746 "ldgram.c"
    break;

  case 229: /* paren_script_name: $@20 '(' NAME ')'  */
#line 953 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_popstate (); (yyval.name) = (yyvsp[-1].name); }
#line 3752 "ldgram.c"
    break;

  case 230: /* $@21: %empty  */
#line 955 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_expression (); }
#line 3758 "ldgram.c"
    break;

  case 231: /* mustbe_exp: $@21 exp  */
#line 957 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_popstate (); (yyval.etree) = (yyvsp[0].etree); }
#line 3764 "ldgram.c"
    break;

  case 232: /* exp: '-' exp  */
#line 962 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop ('-', (yyvsp[0].etree)); }
#line 3770 "ldgram.c"
    break;

  case 233: /* exp: '(' exp ')'  */
#line 964 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = (yyvsp[-1].etree); }
#line 3776 "ldgram.c"
    break;

  case 234: /* exp: NEXT '(' exp ')'  */
#line 966 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop ((int) (yyvsp[-3].integer),(yyvsp[-1].etree)); }
#line 3782 "ldgram.c"
    break;

  case 235: /* exp: '!' exp  */
#line 968 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop ('!', (yyvsp[0].etree)); }
#line 3788 "ldgram.c"
    break;

  case 236: /* exp: '+' exp  */
#line 970 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = (yyvsp[0].etree); }
#line 3794 "ldgram.c"
    break;

  case 237: /* exp: '~' exp  */
#line 972 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop ('~', (yyvsp[0].etree));}
#line 3800 "ldgram.c"
    break;

  case 238: /* exp: exp '*' exp  */
#line 975 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('*', (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3806 "ldgram.c"
    break;

  case 239: /* exp: exp '/' exp  */
#line 977 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('/', (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3812 "ldgram.c"
    break;

  case 240: /* exp: exp '%' exp  */
#line 979 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('%', (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3818 "ldgram.c"
    break;

  case 241: /* exp: exp '+' exp  */
#line 981 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('+', (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3824 "ldgram.c"
    break;

  case 242: /* exp: exp '-' exp  */
#line 983 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('-' , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3830 "ldgram.c"
    break;

  case 243: /* exp: exp LSHIFT exp  */
#line 985 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (LSHIFT , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3836 "ldgram.c"
    break;

  case 244: /* exp: exp RSHIFT exp  */
#line 987 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (RSHIFT , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3842 "ldgram.c"
    break;

  case 245: /* exp: exp EQ exp  */
#line 989 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (EQ , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3848 "ldgram.c"
    break;

  case 246: /* exp: exp NE exp  */
#line 991 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (NE , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3854 "ldgram.c"
    break;

  case 247: /* exp: exp LE exp  */
#line 993 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (LE , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3860 "ldgram.c"
    break;

  case 248: /* exp: exp GE exp  */
#line 995 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (GE , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3866 "ldgram.c"
    break;

  case 249: /* exp: exp '<' exp  */
#line 997 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('<' , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3872 "ldgram.c"
    break;

  case 250: /* exp: exp '>' exp  */
#line 999 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('>' , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3878 "ldgram.c"
    break;

  case 251: /* exp: exp '&' exp  */
#line 1001 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('&' , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3884 "ldgram.c"
    break;

  case 252: /* exp: exp '^' exp  */
#line 1003 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('^' , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3890 "ldgram.c"
    break;

  case 253: /* exp: exp '|' exp  */
#line 1005 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop ('|' , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3896 "ldgram.c"
    break;

  case 254: /* exp: exp '?' exp ':' exp  */
#line 1007 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_trinop ('?' , (yyvsp[-4].etree), (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3902 "ldgram.c"
    break;

  case 255: /* exp: exp ANDAND exp  */
#line 1009 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (ANDAND , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3908 "ldgram.c"
    break;

  case 256: /* exp: exp OROR exp  */
#line 1011 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (OROR , (yyvsp[-2].etree), (yyvsp[0].etree)); }
#line 3914 "ldgram.c"
    break;

  case 257: /* exp: DEFINED '(' NAME ')'  */
#line 1013 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (DEFINED, (yyvsp[-1].name)); }
#line 3920 "ldgram.c"
    break;

  case 258: /* exp: INT  */
#line 1015 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_bigintop ((yyvsp[0].bigint).integer, (yyvsp[0].bigint).str); }
#line 3926 "ldgram.c"
    break;

  case 259: /* exp: SIZEOF_HEADERS  */
#line 1017 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (SIZEOF_HEADERS,0); }
#line 3932 "ldgram.c"
    break;

  case 260: /* exp: ALIGNOF paren_script_name  */
#line 1020 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (ALIGNOF, (yyvsp[0].name)); }
#line 3938 "ldgram.c"
    break;

  case 261: /* exp: SIZEOF paren_script_name  */
#line 1022 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (SIZEOF, (yyvsp[0].name)); }
#line 3944 "ldgram.c"
    break;

  case 262: /* exp: ADDR paren_script_name  */
#line 1024 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (ADDR, (yyvsp[0].name)); }
#line 3950 "ldgram.c"
    break;

  case 263: /* exp: LOADADDR paren_script_name  */
#line 1026 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (LOADADDR, (yyvsp[0].name)); }
#line 3956 "ldgram.c"
    break;

  case 264: /* exp: CONSTANT '(' NAME ')'  */
#line 1028 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (CONSTANT,(yyvsp[-1].name)); }
#line 3962 "ldgram.c"
    break;

  case 265: /* exp: ABSOLUTE '(' exp ')'  */
#line 1030 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop (ABSOLUTE, (yyvsp[-1].etree)); }
#line 3968 "ldgram.c"
    break;

  case 266: /* exp: ALIGN_K '(' exp ')'  */
#line 1032 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop (ALIGN_K,(yyvsp[-1].etree)); }
#line 3974 "ldgram.c"
    break;

  case 267: /* exp: ALIGN_K '(' exp ',' exp ')'  */
#line 1034 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (ALIGN_K,(yyvsp[-3].etree),(yyvsp[-1].etree)); }
#line 3980 "ldgram.c"
    break;

  case 268: /* exp: DATA_SEGMENT_ALIGN '(' exp ',' exp ')'  */
#line 1036 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (DATA_SEGMENT_ALIGN, (yyvsp[-3].etree), (yyvsp[-1].etree)); }
#line 3986 "ldgram.c"
    break;

  case 269: /* exp: DATA_SEGMENT_RELRO_END '(' exp ',' exp ')'  */
#line 1038 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (DATA_SEGMENT_RELRO_END, (yyvsp[-1].etree), (yyvsp[-3].etree)); }
#line 3992 "ldgram.c"
    break;

  case 270: /* exp: DATA_SEGMENT_END '(' exp ')'  */
#line 1040 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop (DATA_SEGMENT_END, (yyvsp[-1].etree)); }
#line 3998 "ldgram.c"
    break;

  case 271: /* $@22: %empty  */
#line 1041 "../../binutils-ia16-20230531/ld/ldgram.y"
                              { ldlex_script (); }
#line 4004 "ldgram.c"
    break;

  case 272: /* $@23: %empty  */
#line 1042 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_popstate (); }
#line 4010 "ldgram.c"
    break;

  case 273: /* exp: SEGMENT_START $@22 '(' NAME $@23 ',' exp ')'  */
#line 1043 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { /* The operands to the expression node are
			     placed in the opposite order from the way
			     in which they appear in the script as
			     that allows us to reuse more code in
			     fold_binary.  */
			  (yyval.etree) = exp_binop (SEGMENT_START,
					  (yyvsp[-1].etree),
					  exp_nameop (NAME, (yyvsp[-4].name))); }
#line 4023 "ldgram.c"
    break;

  case 274: /* exp: BLOCK '(' exp ')'  */
#line 1052 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop (ALIGN_K,(yyvsp[-1].etree)); }
#line 4029 "ldgram.c"
    break;

  case 275: /* exp: NAME  */
#line 1054 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (NAME,(yyvsp[0].name)); }
#line 4035 "ldgram.c"
    break;

  case 276: /* exp: MAX_K '(' exp ',' exp ')'  */
#line 1056 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (MAX_K, (yyvsp[-3].etree), (yyvsp[-1].etree) ); }
#line 4041 "ldgram.c"
    break;

  case 277: /* exp: MIN_K '(' exp ',' exp ')'  */
#line 1058 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_binop (MIN_K, (yyvsp[-3].etree), (yyvsp[-1].etree) ); }
#line 4047 "ldgram.c"
    break;

  case 278: /* exp: ASSERT_K '(' exp ',' NAME ')'  */
#line 1060 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_assert ((yyvsp[-3].etree), (yyvsp[-1].name)); }
#line 4053 "ldgram.c"
    break;

  case 279: /* exp: ORIGIN paren_script_name  */
#line 1062 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (ORIGIN, (yyvsp[0].name)); }
#line 4059 "ldgram.c"
    break;

  case 280: /* exp: LENGTH paren_script_name  */
#line 1064 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_nameop (LENGTH, (yyvsp[0].name)); }
#line 4065 "ldgram.c"
    break;

  case 281: /* exp: LOG2CEIL '(' exp ')'  */
#line 1066 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.etree) = exp_unop (LOG2CEIL, (yyvsp[-1].etree)); }
#line 4071 "ldgram.c"
    break;

  case 282: /* memspec_at_opt: AT '>' NAME  */
#line 1071 "../../binutils-ia16-20230531/ld/ldgram.y"
                            { (yyval.name) = (yyvsp[0].name); }
#line 4077 "ldgram.c"
    break;

  case 283: /* memspec_at_opt: %empty  */
#line 1072 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.name) = 0; }
#line 4083 "ldgram.c"
    break;

  case 284: /* opt_at: AT '(' exp ')'  */
#line 1076 "../../binutils-ia16-20230531/ld/ldgram.y"
                               { (yyval.etree) = (yyvsp[-1].etree); }
#line 4089 "ldgram.c"
    break;

  case 285: /* opt_at: %empty  */
#line 1077 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.etree) = 0; }
#line 4095 "ldgram.c"
    break;

  case 286: /* opt_align: ALIGN_K '(' exp ')'  */
#line 1081 "../../binutils-ia16-20230531/ld/ldgram.y"
                                    { (yyval.etree) = (yyvsp[-1].etree); }
#line 4101 "ldgram.c"
    break;

  case 287: /* opt_align: %empty  */
#line 1082 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.etree) = 0; }
#line 4107 "ldgram.c"
    break;

  case 288: /* opt_align_with_input: ALIGN_WITH_INPUT  */
#line 1086 "../../binutils-ia16-20230531/ld/ldgram.y"
                                 { (yyval.token) = ALIGN_WITH_INPUT; }
#line 4113 "ldgram.c"
    break;

  case 289: /* opt_align_with_input: %empty  */
#line 1087 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.token) = 0; }
#line 4119 "ldgram.c"
    break;

  case 290: /* opt_subalign: SUBALIGN '(' exp ')'  */
#line 1091 "../../binutils-ia16-20230531/ld/ldgram.y"
                                     { (yyval.etree) = (yyvsp[-1].etree); }
#line 4125 "ldgram.c"
    break;

  case 291: /* opt_subalign: %empty  */
#line 1092 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.etree) = 0; }
#line 4131 "ldgram.c"
    break;

  case 292: /* sect_constraint: ONLY_IF_RO  */
#line 1096 "../../binutils-ia16-20230531/ld/ldgram.y"
                           { (yyval.token) = ONLY_IF_RO; }
#line 4137 "ldgram.c"
    break;

  case 293: /* sect_constraint: ONLY_IF_RW  */
#line 1097 "../../binutils-ia16-20230531/ld/ldgram.y"
                           { (yyval.token) = ONLY_IF_RW; }
#line 4143 "ldgram.c"
    break;

  case 294: /* sect_constraint: SPECIAL  */
#line 1098 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.token) = SPECIAL; }
#line 4149 "ldgram.c"
    break;

  case 295: /* sect_constraint: %empty  */
#line 1099 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.token) = 0; }
#line 4155 "ldgram.c"
    break;

  case 296: /* $@24: %empty  */
#line 1103 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_expression(); }
#line 4161 "ldgram.c"
    break;

  case 297: /* $@25: %empty  */
#line 1110 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  ldlex_popstate ();
			  ldlex_wild ();
			  lang_enter_output_section_statement ((yyvsp[-7].name), (yyvsp[-5].etree), sectype,
					sectype_value, (yyvsp[-3].etree), (yyvsp[-1].etree), (yyvsp[-4].etree), (yyvsp[0].token), (yyvsp[-2].token));
			}
#line 4172 "ldgram.c"
    break;

  case 298: /* $@26: %empty  */
#line 1119 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_popstate (); }
#line 4178 "ldgram.c"
    break;

  case 299: /* $@27: %empty  */
#line 1121 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  /* fill_opt may have switched the lexer into
			     expression state, and back again, but in
			     order to find the end of the fill
			     expression the parser must look ahead one
			     token.  If it is a NAME, throw it away as
			     it will have been lexed in the wrong
			     state.  */
			  if (yychar == NAME)
			    {
			      yyclearin;
			      ldlex_backup ();
			    }
			  lang_leave_output_section_statement ((yyvsp[0].fill), (yyvsp[-3].name),
							       (yyvsp[-1].section_phdr), (yyvsp[-2].name));
			}
#line 4199 "ldgram.c"
    break;

  case 301: /* $@28: %empty  */
#line 1139 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_expression (); }
#line 4205 "ldgram.c"
    break;

  case 302: /* $@29: %empty  */
#line 1141 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_popstate (); }
#line 4211 "ldgram.c"
    break;

  case 303: /* $@30: %empty  */
#line 1143 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  lang_enter_overlay ((yyvsp[-5].etree), (yyvsp[-2].etree));
			}
#line 4219 "ldgram.c"
    break;

  case 304: /* $@31: %empty  */
#line 1149 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  if (yychar == NAME)
			    {
			      yyclearin;
			      ldlex_backup ();
			    }
			  lang_leave_overlay ((yyvsp[-10].etree), (int) (yyvsp[-11].integer),
					      (yyvsp[0].fill), (yyvsp[-3].name), (yyvsp[-1].section_phdr), (yyvsp[-2].name));
			}
#line 4233 "ldgram.c"
    break;

  case 306: /* $@32: %empty  */
#line 1164 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_expression (); }
#line 4239 "ldgram.c"
    break;

  case 307: /* $@33: %empty  */
#line 1166 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  ldlex_popstate ();
			  lang_add_assignment (exp_assign (".", (yyvsp[0].etree), false));
			}
#line 4248 "ldgram.c"
    break;

  case 309: /* $@34: %empty  */
#line 1172 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  ldfile_open_command_file ((yyvsp[0].name));
			}
#line 4256 "ldgram.c"
    break;

  case 311: /* type: NOLOAD  */
#line 1179 "../../binutils-ia16-20230531/ld/ldgram.y"
                   { sectype = noload_section; }
#line 4262 "ldgram.c"
    break;

  case 312: /* type: DSECT  */
#line 1180 "../../binutils-ia16-20230531/ld/ldgram.y"
                   { sectype = noalloc_section; }
#line 4268 "ldgram.c"
    break;

  case 313: /* type: COPY  */
#line 1181 "../../binutils-ia16-20230531/ld/ldgram.y"
                   { sectype = noalloc_section; }
#line 4274 "ldgram.c"
    break;

  case 314: /* type: INFO  */
#line 1182 "../../binutils-ia16-20230531/ld/ldgram.y"
                   { sectype = noalloc_section; }
#line 4280 "ldgram.c"
    break;

  case 315: /* type: OVERLAY  */
#line 1183 "../../binutils-ia16-20230531/ld/ldgram.y"
                   { sectype = noalloc_section; }
#line 4286 "ldgram.c"
    break;

  case 316: /* type: READONLY '(' TYPE '=' exp ')'  */
#line 1184 "../../binutils-ia16-20230531/ld/ldgram.y"
                                         { sectype = typed_readonly_section; sectype_value = (yyvsp[-1].etree); }
#line 4292 "ldgram.c"
    break;

  case 317: /* type: READONLY  */
#line 1185 "../../binutils-ia16-20230531/ld/ldgram.y"
                    { sectype = readonly_section; }
#line 4298 "ldgram.c"
    break;

  case 318: /* type: TYPE '=' exp  */
#line 1186 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { sectype = type_section; sectype_value = (yyvsp[0].etree); }
#line 4304 "ldgram.c"
    break;

  case 320: /* atype: %empty  */
#line 1191 "../../binutils-ia16-20230531/ld/ldgram.y"
                            { sectype = normal_section; }
#line 4310 "ldgram.c"
    break;

  case 321: /* atype: '(' ')'  */
#line 1192 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { sectype = normal_section; }
#line 4316 "ldgram.c"
    break;

  case 322: /* opt_exp_with_type: exp atype ':'  */
#line 1196 "../../binutils-ia16-20230531/ld/ldgram.y"
                                        { (yyval.etree) = (yyvsp[-2].etree); }
#line 4322 "ldgram.c"
    break;

  case 323: /* opt_exp_with_type: atype ':'  */
#line 1197 "../../binutils-ia16-20230531/ld/ldgram.y"
                                        { (yyval.etree) = (etree_type *)NULL;  }
#line 4328 "ldgram.c"
    break;

  case 324: /* opt_exp_with_type: BIND '(' exp ')' atype ':'  */
#line 1202 "../../binutils-ia16-20230531/ld/ldgram.y"
                                           { (yyval.etree) = (yyvsp[-3].etree); }
#line 4334 "ldgram.c"
    break;

  case 325: /* opt_exp_with_type: BIND '(' exp ')' BLOCK '(' exp ')' atype ':'  */
#line 1204 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.etree) = (yyvsp[-7].etree); }
#line 4340 "ldgram.c"
    break;

  case 326: /* opt_exp_without_type: exp ':'  */
#line 1208 "../../binutils-ia16-20230531/ld/ldgram.y"
                                { (yyval.etree) = (yyvsp[-1].etree); }
#line 4346 "ldgram.c"
    break;

  case 327: /* opt_exp_without_type: ':'  */
#line 1209 "../../binutils-ia16-20230531/ld/ldgram.y"
                                { (yyval.etree) = (etree_type *) NULL;  }
#line 4352 "ldgram.c"
    break;

  case 328: /* opt_nocrossrefs: %empty  */
#line 1214 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.integer) = 0; }
#line 4358 "ldgram.c"
    break;

  case 329: /* opt_nocrossrefs: NOCROSSREFS  */
#line 1216 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { (yyval.integer) = 1; }
#line 4364 "ldgram.c"
    break;

  case 330: /* memspec_opt: '>' NAME  */
#line 1221 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.name) = (yyvsp[0].name); }
#line 4370 "ldgram.c"
    break;

  case 331: /* memspec_opt: %empty  */
#line 1222 "../../binutils-ia16-20230531/ld/ldgram.y"
                { (yyval.name) = DEFAULT_MEMORY_REGION; }
#line 4376 "ldgram.c"
    break;

  case 332: /* phdr_opt: %empty  */
#line 1227 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.section_phdr) = NULL;
		}
#line 4384 "ldgram.c"
    break;

  case 333: /* phdr_opt: phdr_opt ':' NAME  */
#line 1231 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  struct lang_output_section_phdr_list *n;

		  n = ((struct lang_output_section_phdr_list *)
		       xmalloc (sizeof *n));
		  n->name = (yyvsp[0].name);
		  n->used = false;
		  n->next = (yyvsp[-2].section_phdr);
		  (yyval.section_phdr) = n;
		}
#line 4399 "ldgram.c"
    break;

  case 335: /* $@35: %empty  */
#line 1247 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  ldlex_wild ();
			  lang_enter_overlay_section ((yyvsp[0].name));
			}
#line 4408 "ldgram.c"
    break;

  case 336: /* $@36: %empty  */
#line 1254 "../../binutils-ia16-20230531/ld/ldgram.y"
                        { ldlex_popstate (); }
#line 4414 "ldgram.c"
    break;

  case 337: /* $@37: %empty  */
#line 1256 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  if (yychar == NAME)
			    {
			      yyclearin;
			      ldlex_backup ();
			    }
			  lang_leave_overlay_section ((yyvsp[0].fill), (yyvsp[-1].section_phdr));
			}
#line 4427 "ldgram.c"
    break;

  case 342: /* $@38: %empty  */
#line 1277 "../../binutils-ia16-20230531/ld/ldgram.y"
                     { ldlex_expression (); }
#line 4433 "ldgram.c"
    break;

  case 343: /* $@39: %empty  */
#line 1278 "../../binutils-ia16-20230531/ld/ldgram.y"
                                            { ldlex_popstate (); }
#line 4439 "ldgram.c"
    break;

  case 344: /* phdr: NAME $@38 phdr_type phdr_qualifiers $@39 ';'  */
#line 1280 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_new_phdr ((yyvsp[-5].name), (yyvsp[-3].etree), (yyvsp[-2].phdr).filehdr, (yyvsp[-2].phdr).phdrs, (yyvsp[-2].phdr).at,
				 (yyvsp[-2].phdr).flags);
		}
#line 4448 "ldgram.c"
    break;

  case 345: /* phdr_type: exp  */
#line 1288 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.etree) = (yyvsp[0].etree);

		  if ((yyvsp[0].etree)->type.node_class == etree_name
		      && (yyvsp[0].etree)->type.node_code == NAME)
		    {
		      const char *s;
		      unsigned int i;
		      static const char * const phdr_types[] =
			{
			  "PT_NULL", "PT_LOAD", "PT_DYNAMIC",
			  "PT_INTERP", "PT_NOTE", "PT_SHLIB",
			  "PT_PHDR", "PT_TLS"
			};

		      s = (yyvsp[0].etree)->name.name;
		      for (i = 0;
			   i < sizeof phdr_types / sizeof phdr_types[0];
			   i++)
			if (strcmp (s, phdr_types[i]) == 0)
			  {
			    (yyval.etree) = exp_intop (i);
			    break;
			  }
		      if (i == sizeof phdr_types / sizeof phdr_types[0])
			{
			  if (strcmp (s, "PT_GNU_EH_FRAME") == 0)
			    (yyval.etree) = exp_intop (0x6474e550);
			  else if (strcmp (s, "PT_GNU_STACK") == 0)
			    (yyval.etree) = exp_intop (0x6474e551);
			  else if (strcmp (s, "PT_GNU_RELRO") == 0)
			    (yyval.etree) = exp_intop (0x6474e552);
			  else if (strcmp (s, "PT_GNU_PROPERTY") == 0)
			    (yyval.etree) = exp_intop (0x6474e553);
			  else
			    {
			      einfo (_("\
%X%P:%pS: unknown phdr type `%s' (try integer literal)\n"),
				     NULL, s);
			      (yyval.etree) = exp_intop (0);
			    }
			}
		    }
		}
#line 4497 "ldgram.c"
    break;

  case 346: /* phdr_qualifiers: %empty  */
#line 1336 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  memset (&(yyval.phdr), 0, sizeof (struct phdr_info));
		}
#line 4505 "ldgram.c"
    break;

  case 347: /* phdr_qualifiers: NAME phdr_val phdr_qualifiers  */
#line 1340 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.phdr) = (yyvsp[0].phdr);
		  if (strcmp ((yyvsp[-2].name), "FILEHDR") == 0 && (yyvsp[-1].etree) == NULL)
		    (yyval.phdr).filehdr = true;
		  else if (strcmp ((yyvsp[-2].name), "PHDRS") == 0 && (yyvsp[-1].etree) == NULL)
		    (yyval.phdr).phdrs = true;
		  else if (strcmp ((yyvsp[-2].name), "FLAGS") == 0 && (yyvsp[-1].etree) != NULL)
		    (yyval.phdr).flags = (yyvsp[-1].etree);
		  else
		    einfo (_("%X%P:%pS: PHDRS syntax error at `%s'\n"),
			   NULL, (yyvsp[-2].name));
		}
#line 4522 "ldgram.c"
    break;

  case 348: /* phdr_qualifiers: AT '(' exp ')' phdr_qualifiers  */
#line 1353 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.phdr) = (yyvsp[0].phdr);
		  (yyval.phdr).at = (yyvsp[-2].etree);
		}
#line 4531 "ldgram.c"
    break;

  case 349: /* phdr_val: %empty  */
#line 1361 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.etree) = NULL;
		}
#line 4539 "ldgram.c"
    break;

  case 350: /* phdr_val: '(' exp ')'  */
#line 1365 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.etree) = (yyvsp[-1].etree);
		}
#line 4547 "ldgram.c"
    break;

  case 351: /* $@40: %empty  */
#line 1371 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_version_file ();
		  PUSH_ERROR (_("dynamic list"));
		}
#line 4556 "ldgram.c"
    break;

  case 352: /* dynamic_list_file: $@40 dynamic_list_nodes  */
#line 1376 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_popstate ();
		  POP_ERROR ();
		}
#line 4565 "ldgram.c"
    break;

  case 356: /* dynamic_list_tag: vers_defns ';'  */
#line 1393 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_append_dynamic_list (current_dynamic_list_p, (yyvsp[-1].versyms));
		}
#line 4573 "ldgram.c"
    break;

  case 357: /* $@41: %empty  */
#line 1401 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_version_file ();
		  PUSH_ERROR (_("VERSION script"));
		}
#line 4582 "ldgram.c"
    break;

  case 358: /* version_script_file: $@41 vers_nodes  */
#line 1406 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_popstate ();
		  POP_ERROR ();
		}
#line 4591 "ldgram.c"
    break;

  case 359: /* $@42: %empty  */
#line 1415 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_version_script ();
		}
#line 4599 "ldgram.c"
    break;

  case 360: /* version: $@42 VERSIONK '{' vers_nodes '}'  */
#line 1419 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  ldlex_popstate ();
		}
#line 4607 "ldgram.c"
    break;

  case 363: /* vers_node: '{' vers_tag '}' ';'  */
#line 1431 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_register_vers_node (NULL, (yyvsp[-2].versnode), NULL);
		}
#line 4615 "ldgram.c"
    break;

  case 364: /* vers_node: VERS_TAG '{' vers_tag '}' ';'  */
#line 1435 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_register_vers_node ((yyvsp[-4].name), (yyvsp[-2].versnode), NULL);
		}
#line 4623 "ldgram.c"
    break;

  case 365: /* vers_node: VERS_TAG '{' vers_tag '}' verdep ';'  */
#line 1439 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  lang_register_vers_node ((yyvsp[-5].name), (yyvsp[-3].versnode), (yyvsp[-1].deflist));
		}
#line 4631 "ldgram.c"
    break;

  case 366: /* verdep: VERS_TAG  */
#line 1446 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.deflist) = lang_add_vers_depend (NULL, (yyvsp[0].name));
		}
#line 4639 "ldgram.c"
    break;

  case 367: /* verdep: verdep VERS_TAG  */
#line 1450 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.deflist) = lang_add_vers_depend ((yyvsp[-1].deflist), (yyvsp[0].name));
		}
#line 4647 "ldgram.c"
    break;

  case 368: /* vers_tag: %empty  */
#line 1457 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versnode) = lang_new_vers_node (NULL, NULL);
		}
#line 4655 "ldgram.c"
    break;

  case 369: /* vers_tag: vers_defns ';'  */
#line 1461 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versnode) = lang_new_vers_node ((yyvsp[-1].versyms), NULL);
		}
#line 4663 "ldgram.c"
    break;

  case 370: /* vers_tag: GLOBAL ':' vers_defns ';'  */
#line 1465 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versnode) = lang_new_vers_node ((yyvsp[-1].versyms), NULL);
		}
#line 4671 "ldgram.c"
    break;

  case 371: /* vers_tag: LOCAL ':' vers_defns ';'  */
#line 1469 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versnode) = lang_new_vers_node (NULL, (yyvsp[-1].versyms));
		}
#line 4679 "ldgram.c"
    break;

  case 372: /* vers_tag: GLOBAL ':' vers_defns ';' LOCAL ':' vers_defns ';'  */
#line 1473 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versnode) = lang_new_vers_node ((yyvsp[-5].versyms), (yyvsp[-1].versyms));
		}
#line 4687 "ldgram.c"
    break;

  case 373: /* vers_defns: VERS_IDENTIFIER  */
#line 1480 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern (NULL, (yyvsp[0].name), ldgram_vers_current_lang, false);
		}
#line 4695 "ldgram.c"
    break;

  case 374: /* vers_defns: NAME  */
#line 1484 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern (NULL, (yyvsp[0].name), ldgram_vers_current_lang, true);
		}
#line 4703 "ldgram.c"
    break;

  case 375: /* vers_defns: vers_defns ';' VERS_IDENTIFIER  */
#line 1488 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern ((yyvsp[-2].versyms), (yyvsp[0].name), ldgram_vers_current_lang, false);
		}
#line 4711 "ldgram.c"
    break;

  case 376: /* vers_defns: vers_defns ';' NAME  */
#line 1492 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern ((yyvsp[-2].versyms), (yyvsp[0].name), ldgram_vers_current_lang, true);
		}
#line 4719 "ldgram.c"
    break;

  case 377: /* @43: %empty  */
#line 1496 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.name) = ldgram_vers_current_lang;
			  ldgram_vers_current_lang = (yyvsp[-1].name);
			}
#line 4728 "ldgram.c"
    break;

  case 378: /* vers_defns: vers_defns ';' EXTERN NAME '{' @43 vers_defns opt_semicolon '}'  */
#line 1501 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  struct bfd_elf_version_expr *pat;
			  for (pat = (yyvsp[-2].versyms); pat->next != NULL; pat = pat->next);
			  pat->next = (yyvsp[-8].versyms);
			  (yyval.versyms) = (yyvsp[-2].versyms);
			  ldgram_vers_current_lang = (yyvsp[-3].name);
			}
#line 4740 "ldgram.c"
    break;

  case 379: /* @44: %empty  */
#line 1509 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.name) = ldgram_vers_current_lang;
			  ldgram_vers_current_lang = (yyvsp[-1].name);
			}
#line 4749 "ldgram.c"
    break;

  case 380: /* vers_defns: EXTERN NAME '{' @44 vers_defns opt_semicolon '}'  */
#line 1514 "../../binutils-ia16-20230531/ld/ldgram.y"
                        {
			  (yyval.versyms) = (yyvsp[-2].versyms);
			  ldgram_vers_current_lang = (yyvsp[-3].name);
			}
#line 4758 "ldgram.c"
    break;

  case 381: /* vers_defns: GLOBAL  */
#line 1519 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern (NULL, "global", ldgram_vers_current_lang, false);
		}
#line 4766 "ldgram.c"
    break;

  case 382: /* vers_defns: vers_defns ';' GLOBAL  */
#line 1523 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern ((yyvsp[-2].versyms), "global", ldgram_vers_current_lang, false);
		}
#line 4774 "ldgram.c"
    break;

  case 383: /* vers_defns: LOCAL  */
#line 1527 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern (NULL, "local", ldgram_vers_current_lang, false);
		}
#line 4782 "ldgram.c"
    break;

  case 384: /* vers_defns: vers_defns ';' LOCAL  */
#line 1531 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern ((yyvsp[-2].versyms), "local", ldgram_vers_current_lang, false);
		}
#line 4790 "ldgram.c"
    break;

  case 385: /* vers_defns: EXTERN  */
#line 1535 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern (NULL, "extern", ldgram_vers_current_lang, false);
		}
#line 4798 "ldgram.c"
    break;

  case 386: /* vers_defns: vers_defns ';' EXTERN  */
#line 1539 "../../binutils-ia16-20230531/ld/ldgram.y"
                {
		  (yyval.versyms) = lang_new_vers_pattern ((yyvsp[-2].versyms), "extern", ldgram_vers_current_lang, false);
		}
#line 4806 "ldgram.c"
    break;


#line 4810 "ldgram.c"

      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", YY_CAST (yysymbol_kind_t, yyr1[yyn]), &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */
  {
    const int yylhs = yyr1[yyn] - YYNTOKENS;
    const int yyi = yypgoto[yylhs] + *yyssp;
    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
               ? yytable[yyi]
               : yydefgoto[yylhs]);
  }

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
      yyerror (YY_("syntax error"));
    }

  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:
  /* Pacify compilers when the user code never invokes YYERROR and the
     label yyerrorlab therefore never appears in user code.  */
  if (0)
    YYERROR;
  ++yynerrs;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  /* Pop stack until we find a state that shifts the error token.  */
  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYSYMBOL_YYerror;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYSYMBOL_YYerror)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  YY_ACCESSING_SYMBOL (yystate), yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", YY_ACCESSING_SYMBOL (yyn), yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturnlab;


/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturnlab;


/*-----------------------------------------------------------.
| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
`-----------------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  goto yyreturnlab;


/*----------------------------------------------------------.
| yyreturnlab -- parsing is finished, clean up and return.  |
`----------------------------------------------------------*/
yyreturnlab:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  YY_ACCESSING_SYMBOL (+*yyssp), yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif

  return yyresult;
}

#line 1549 "../../binutils-ia16-20230531/ld/ldgram.y"

void
yyerror(arg)
     const char *arg;
{
  if (ldfile_assumed_script)
    einfo (_("%P:%s: file format not recognized; treating as linker script\n"),
	   ldlex_filename ());
  if (error_index > 0 && error_index < ERROR_NAME_MAX)
    einfo ("%F%P:%pS: %s in %s\n", NULL, arg, error_names[error_index - 1]);
  else
    einfo ("%F%P:%pS: %s\n", NULL, arg);
}
